@@ -1,4 +1,5 @@
 {-# OPTIONS -cpp #-}
+{-# LANGUAGE CPP, ForeignFunctionInterface #-}
 
 ------------------------------------------------------------------------
 -- Program for converting .hsc files to .hs files, by converting the
@@ -9,81 +10,50 @@
 --
 -- See the documentation in the Users' Guide for more details.
 
-import Control.Monad		( MonadPlus(..), liftM, liftM2, when )
-import Data.Char		( isAlpha, isAlphaNum, isSpace, isDigit,
-				  toUpper, intToDigit, ord )
-import Data.List		( intersperse, isSuffixOf )
-import System.Cmd		( system, rawSystem )
-import System.Console.GetOpt
-import System.Directory		( removeFile, doesFileExist )
-import System.Environment	( getProgName, getArgs )
-import System.Exit		( ExitCode(..), exitWith )
-import System.IO		( hPutStr, hPutStrLn, stderr )
-
-#if __GLASGOW_HASKELL__ >= 604 || defined(__NHC__) || defined(__HUGS__)
-import System.Directory		( findExecutable )
-#else
-import System.Directory		( getPermissions, executable )
-import System.Environment	( getEnv )
-import Control.Monad		( foldM )
+#if defined(__GLASGOW_HASKELL__) && !defined(BUILD_NHC)
+#include "../../includes/ghcconfig.h"
 #endif
 
+import Control.Monad            ( MonadPlus(..), liftM, liftM2, when )
+import Data.Char                ( isAlpha, isAlphaNum, isSpace, isDigit,
+                                  toUpper, intToDigit, ord )
+import Data.List                ( intersperse, isSuffixOf )
+import System.Console.GetOpt
+
+#if defined(mingw32_HOST_OS)
+import Foreign
+import Foreign.C.String
+#endif
+import System.Directory         ( removeFile, doesFileExist, findExecutable )
+import System.Environment       ( getProgName, getArgs )
+import System.Exit              ( ExitCode(..), exitWith )
+import System.IO
+
 #if __GLASGOW_HASKELL__ >= 604
 import System.Process           ( runProcess, waitForProcess )
-import System.IO                ( openFile, IOMode(..), hClose )
 #define HAVE_runProcess
 #endif
 
-#if ! BUILD_NHC
-import Paths_hsc2hs		( getDataFileName, version )
-import Data.Version		( showVersion )
+import System.Cmd               ( rawSystem )
+#ifndef HAVE_runProcess
+import System.Cmd               ( system )
+#endif
+
+import IO                ( bracket_ )
+
+#ifndef BUILD_NHC
+import Paths_hsc2hs as Main     ( getDataFileName, version )
+import Data.Version             ( showVersion )
 #else
-import System.Directory		( getCurrentDirectory )
+import System.Directory         ( getCurrentDirectory )
 getDataFileName s = do here <- getCurrentDirectory
                        return (here++"/"++s)
 version = "0.67" -- TODO!!!
 showVersion = id
 #endif
 
-#ifdef __GLASGOW_HASKELL__
-default_compiler = "ghc"
-#else
+default_compiler :: String
 default_compiler = "gcc"
-#endif
-
-#if defined(__GLASGOW_HASKELL__) && (__GLASGOW_HASKELL__ < 604)
-findExecutable :: String -> IO (Maybe FilePath)
-findExecutable cmd =
-  let dir = dirname cmd
-  in case dir of
-    "" -> do -- search the shell environment PATH variable for candidates
-             val <- getEnv "PATH"
-             let psep = pathSep val
-                 dirs = splitPath psep "" val
-             foldM (\a dir-> testFile a (dir++'/':cmd)) Nothing dirs
-    _  -> do testFile Nothing cmd
-  where
-    splitPath :: Char -> String -> String -> [String]
-    splitPath sep acc []                 = [reverse acc]
-    splitPath sep acc (c:path) | c==sep  = reverse acc : splitPath sep "" path
-    splitPath sep acc (c:path)           = splitPath sep (c:acc) path
-
-    pathSep s = if length (filter (==';') s) >0 then ';' else ':'
-
-    testFile :: Maybe String -> String -> IO (Maybe String)
-    testFile gotit@(Just _) path = return gotit
-    testFile Nothing path = do
-        ok <- doesFileExist path
-        if ok then perms path else return Nothing
-
-    perms file = do
-        p <- getPermissions file
-        return (if executable p then Just file else Nothing)
-
-    dirname  = reverse . safetail . dropWhile (not.(`elem`"\\/")) . reverse
-      where safetail [] = []
-            safetail (_:x) = x
-#endif
 
 versionString :: String
 versionString = "hsc2hs version " ++ showVersion version ++ "\n"
@@ -152,14 +122,52 @@ main = do
     args <- getArgs
     let (flags, files, errs) = getOpt Permute options args
 
-	-- If there is no Template flag explicitly specified,
-	-- use the file placed by the Cabal installation.
-    flags_w_tpl <-
-	if any template_flag flags then
-	    return flags
-	  else do
-	    templ <- getDataFileName "template-hsc.h"
-	    return (Template templ : flags)
+    -- If there is no Template flag explicitly specified, try
+    -- to find one. We first look near the executable.  This only
+    -- works on Win32 or Hugs (getExecDir). If this finds a template
+    -- file then it's certainly the one we want, even if hsc2hs isn't
+    -- installed where we told Cabal it would be installed.
+    --
+    -- Next we try the location we told Cabal about.
+    --
+    -- If neither of the above work, then hopefully we're on Unix and
+    -- there's a wrapper script which specifies an explicit template flag.
+    mb_libdir <- getLibDir
+
+    flags_w_tpl0 <-
+        if any template_flag flags then return flags
+        else do mb_templ1 <-
+                   case mb_libdir of
+                   Nothing   -> return Nothing
+                   Just path -> do
+                   -- Euch, this is horrible. Unfortunately
+                   -- Paths_hsc2hs isn't too useful for a
+                   -- relocatable binary, though.
+                     let 
+#if defined(NEW_GHC_LAYOUT)
+                         templ1 = path ++ "/template-hsc.h"
+#else
+                         templ1 = path ++ "/hsc2hs-" ++ showVersion Main.version ++ "/template-hsc.h"
+#endif
+                         incl = path ++ "/include/"
+                     exists1 <- doesFileExist templ1
+                     if exists1
+                        then return $ Just (Template templ1,
+                                            CompFlag ("-I" ++ incl))
+                        else return Nothing
+                case mb_templ1 of
+                    Just (templ1, incl) -> return (templ1 : flags ++ [incl])
+                    Nothing -> do
+                        templ2 <- getDataFileName "template-hsc.h"
+                        exists2 <- doesFileExist templ2
+                        if exists2 then return (Template templ2 : flags)
+                                   else return flags
+
+    -- take only the last --template flag on the cmd line
+    let
+      (before,tpl:after) = break template_flag (reverse flags_w_tpl0)
+      flags_w_tpl = reverse (before ++ tpl : filter (not.template_flag) after)
+
     case (files, errs) of
         (_, _)
             | any isHelp    flags_w_tpl -> bye (usageInfo header options)
@@ -167,7 +175,7 @@ main = do
             where
             isHelp    Help    = True; isHelp    _ = False
             isVersion Version = True; isVersion _ = False
-        ((_:_), []) -> mapM_ (processFile flags_w_tpl) files
+        ((_:_), []) -> mapM_ (processFile flags_w_tpl mb_libdir) files
         (_,     _ ) -> die (concat errs ++ usageInfo header options)
 
 getProgramName :: IO String
@@ -182,13 +190,21 @@ bye s = putStr s >> exitWith ExitSuccess
 die :: String -> IO a
 die s = hPutStr stderr s >> exitWith (ExitFailure 1)
 
-processFile :: [Flag] -> String -> IO ()
-processFile flags name
+processFile :: [Flag] -> Maybe String -> String -> IO ()
+processFile flags mb_libdir name
   = do let file_name = dosifyPath name
-       s <- readFile file_name
+       h <- openBinaryFile file_name ReadMode
+       -- use binary mode so we pass through UTF-8, see GHC ticket #3837
+       -- But then on Windows we end up turning things like
+       --     #let alignment t = e^M
+       -- into
+       --     #define hsc_alignment(t ) printf ( e^M);
+       -- which gcc doesn't like, so strip out any ^M characters.
+       s <- hGetContents h
+       let s' = filter ('\r' /=) s
        case parser of
-    	   Parser p -> case p (SourcePos file_name 1) s of
-    	       Success _ _ _ toks -> output flags file_name toks
+    	   Parser p -> case p (SourcePos file_name 1) s' of
+    	       Success _ _ _ toks -> output mb_libdir flags file_name toks
     	       Failure (SourcePos name' line) msg ->
     		   die (name'++":"++show line++": "++msg++"\n")
 
@@ -259,15 +275,16 @@ satisfy p =
         c:cs | p c -> Success (updatePos pos c) [c] cs c
         _          -> Failure pos "Bad character"
 
+satisfy_ :: (Char -> Bool) -> Parser ()
+satisfy_ p = satisfy p >> return ()
+
 char_ :: Char -> Parser ()
 char_ c = do
-    satisfy (== c) `message` (show c++" expected")
-    return ()
+    satisfy_ (== c) `message` (show c++" expected")
 
 anyChar_ :: Parser ()
 anyChar_ = do
-    satisfy (const True) `message` "Unexpected end of file"
-    return ()
+    satisfy_ (const True) `message` "Unexpected end of file"
 
 any2Chars_ :: Parser ()
 any2Chars_ = anyChar_ >> anyChar_
@@ -362,10 +379,10 @@ linePragma :: Parser ()
 linePragma = do
     char_ '#'
     manySatisfy_ isSpace
-    satisfy (\c -> c == 'L' || c == 'l')
-    satisfy (\c -> c == 'I' || c == 'i')
-    satisfy (\c -> c == 'N' || c == 'n')
-    satisfy (\c -> c == 'E' || c == 'e')
+    satisfy_ (\c -> c == 'L' || c == 'l')
+    satisfy_ (\c -> c == 'I' || c == 'i')
+    satisfy_ (\c -> c == 'N' || c == 'n')
+    satisfy_ (\c -> c == 'E' || c == 'e')
     manySatisfy1_ isSpace
     line <- liftM read $ manySatisfy1 isDigit
     manySatisfy1_ isSpace
@@ -407,15 +424,14 @@ satisfyC p = do
         '\\':'\n':_ -> do any2Chars_ `fakeOutput` []; satisfyC p
         _           -> satisfy p
 
+satisfyC_ :: (Char -> Bool) -> Parser ()
+satisfyC_ p = satisfyC p >> return ()
+
 charC_ :: Char -> Parser ()
-charC_ c = do
-    satisfyC (== c) `message` (show c++" expected")
-    return ()
+charC_ c = satisfyC_ (== c) `message` (show c++" expected")
 
 anyCharC_ :: Parser ()
-anyCharC_ = do
-    satisfyC (const True) `message` "Unexpected end of file"
-    return ()
+anyCharC_ = satisfyC_ (const True) `message` "Unexpected end of file"
 
 any2CharsC_ :: Parser ()
 any2CharsC_ = anyCharC_ >> anyCharC_
@@ -514,8 +530,8 @@ splitExt name =
             where
             (restBase, restExt) = splitExt rest
 
-output :: [Flag] -> String -> [Token] -> IO ()
-output flags name toks = do
+output :: Maybe String -> [Flag] -> String -> [Token] -> IO ()
+output mb_libdir flags name toks = do
 
     (outName, outDir, outBase) <- case [f | Output f <- flags] of
         [] -> if not (null ext) && last ext == 'c'
@@ -563,17 +579,26 @@ output flags name toks = do
 
     compiler <- case [c | Compiler c <- flags] of
         []  -> do
-	    mb_path <- findExecutable default_compiler
-	    case mb_path of
-		Nothing -> die ("Can't find "++default_compiler++"\n")
-		Just path -> return path
-        [c] -> return c
-        _   -> onlyOne "compiler"
+                  -- if this hsc2hs is part of a GHC installation on
+                  -- Windows, then we should use the mingw gcc that
+                  -- comes with GHC (#3929)
+                  case mb_libdir of
+                    Nothing -> search_path   
+                    Just d  -> do
+                      let inplace_gcc = d ++ "/../mingw/bin/gcc.exe"
+                      b <- doesFileExist inplace_gcc
+                      if b then return inplace_gcc else search_path
+            where
+                search_path = do
+                  mb_path <- findExecutable default_compiler
+                  case mb_path of
+                      Nothing -> die ("Can't find "++default_compiler++"\n")
+                      Just path -> return path
+        cs  -> return (last cs)
 
     linker <- case [l | Linker l <- flags] of
         []  -> return compiler
-        [l] -> return l
-        _   -> onlyOne "linker"
+        ls  -> return (last ls)
 
     writeFile cProgName $
         concatMap outFlagHeaderCProg flags++
@@ -591,55 +616,53 @@ output flags name toks = do
 
     rawSystemL ("compiling " ++ cProgName) beVerbose compiler
 	(  ["-c"]
-        ++ [f | CompFlag f <- flags]
         ++ [cProgName]
         ++ ["-o", oProgName]
+        ++ [f | CompFlag f <- flags]
 	)
-    removeFile cProgName
+    finallyRemove cProgName $ do
 
-    rawSystemL ("linking " ++ oProgName) beVerbose linker
-        (  [f | LinkFlag f <- flags]
-        ++ [oProgName]
+      rawSystemL ("linking " ++ oProgName) beVerbose linker
+        (  [oProgName]
         ++ ["-o", progName]
+        ++ [f | LinkFlag f <- flags]
 	)
-    removeFile oProgName
+      finallyRemove oProgName $ do
 
-    rawSystemWithStdOutL ("running " ++ execProgName) beVerbose execProgName [] outName
-    removeFile progName
+        rawSystemWithStdOutL ("running " ++ execProgName) beVerbose execProgName [] outName
+        finallyRemove progName $ do
 
-    when needsH $ writeFile outHName $
-        "#ifndef "++includeGuard++"\n" ++
-        "#define "++includeGuard++"\n" ++
-        "#if __GLASGOW_HASKELL__ && __GLASGOW_HASKELL__ < 409\n" ++
-        "#include <Rts.h>\n" ++
-        "#endif\n" ++
-        "#include <HsFFI.h>\n" ++
-        "#if __NHC__\n" ++
-        "#undef HsChar\n" ++
-        "#define HsChar int\n" ++
-        "#endif\n" ++
-        concatMap outFlagH flags++
-        concatMap outTokenH specials++
-        "#endif\n"
+          when needsH $ writeFile outHName $
+            "#ifndef "++includeGuard++"\n" ++
+            "#define "++includeGuard++"\n" ++
+            "#if __GLASGOW_HASKELL__ && __GLASGOW_HASKELL__ < 409\n" ++
+            "#include <Rts.h>\n" ++
+            "#endif\n" ++
+            "#include <HsFFI.h>\n" ++
+            "#if __NHC__\n" ++
+            "#undef HsChar\n" ++
+            "#define HsChar int\n" ++
+            "#endif\n" ++
+            concatMap outFlagH flags++
+            concatMap outTokenH specials++
+            "#endif\n"
 
-    when needsC $ writeFile outCName $
-        "#include \""++outHFile++"\"\n"++
-        concatMap outTokenC specials
-	-- NB. outHFile not outHName; works better when processed
-	-- by gcc or mkdependC.
+          when needsC $ writeFile outCName $
+            "#include \""++outHFile++"\"\n"++
+            concatMap outTokenC specials
+            -- NB. outHFile not outHName; works better when processed
+            -- by gcc or mkdependC.
 
 rawSystemL :: String -> Bool -> FilePath -> [String] -> IO ()
 rawSystemL action flg prog args = do
   let cmdLine = prog++" "++unwords args
   when flg $ hPutStrLn stderr ("Executing: " ++ cmdLine)
-#ifndef HAVE_rawSystem
-  exitStatus <- system cmdLine
-#else
   exitStatus <- rawSystem prog args
-#endif
   case exitStatus of
-    ExitFailure _ -> die $ action ++ " failed\ncommand was: " ++ cmdLine ++ "\n"
-    _             -> return ()
+    ExitFailure exitCode -> die $ action ++ " failed "
+                               ++ "(exit code " ++ show exitCode ++ ")\n"
+                               ++ "command was: " ++ cmdLine ++ "\n"
+    _                    -> return ()
 
 rawSystemWithStdOutL :: String -> Bool -> FilePath -> [String] -> FilePath -> IO ()
 rawSystemWithStdOutL action flg prog args outFile = do
@@ -654,8 +677,23 @@ rawSystemWithStdOutL action flg prog args outFile = do
   hClose hOut
 #endif
   case exitStatus of
-    ExitFailure _ -> die $ action ++ " failed\ncommand was: " ++ cmdLine ++ "\n"
-    _             -> return ()
+    ExitFailure exitCode -> die $ action ++ " failed "
+                               ++ "(exit code " ++ show exitCode ++ ")\n"
+                               ++ "command was: " ++ cmdLine ++ "\n"
+    _                    -> return ()
+
+-- delay the cleanup of generated files until the end; attempts to
+-- get around intermittent failure to delete files which has
+-- just been exec'ed by a sub-process (Win32 only.)
+finallyRemove :: FilePath -> IO a -> IO a
+finallyRemove fp act =
+  bracket_ (return fp)
+           (const $ noisyRemove fp)
+           act
+ where
+  noisyRemove fpath =
+    catch (removeFile fpath)
+          (\ e -> hPutStrLn stderr ("Failed to remove file " ++ fpath ++ "; error= " ++ show e))
 
 onlyOne :: String -> IO a
 onlyOne what = die ("Only one "++what++" may be specified\n")
@@ -730,7 +768,7 @@ outHeaderHs flags inH toks =
 	"#if __GLASGOW_HASKELL__ && __GLASGOW_HASKELL__ < 603\n" ++
 	"    printf (\"{-# OPTIONS -#include %s #-}\\n\", \""++
                   showCString s++"\");\n"++
-	"#else\n"++
+	"#elif __GLASGOW_HASKELL__ < 610\n"++
 	"    printf (\"{-# INCLUDE %s #-}\\n\", \""++
                   showCString s++"\");\n"++
 	"#endif\n"
@@ -878,3 +916,36 @@ subst _ _ = id
 
 dosifyPath :: String -> String
 dosifyPath = subst '/' '\\'
+
+getLibDir :: IO (Maybe String)
+#if defined(NEW_GHC_LAYOUT)
+getLibDir = fmap (fmap (++ "/lib")) $ getExecDir "/bin/hsc2hs.exe"
+#else
+getLibDir = getExecDir "/bin/hsc2hs.exe"
+#endif
+
+-- (getExecDir cmd) returns the directory in which the current
+--                  executable, which should be called 'cmd', is running
+-- So if the full path is /a/b/c/d/e, and you pass "d/e" as cmd,
+-- you'll get "/a/b/c" back as the result
+getExecDir :: String -> IO (Maybe String)
+getExecDir cmd =
+    getExecPath >>= maybe (return Nothing) removeCmdSuffix
+    where unDosifyPath = subst '\\' '/'
+          initN n = reverse . drop n . reverse
+          removeCmdSuffix = return . Just . initN (length cmd) . unDosifyPath
+
+getExecPath :: IO (Maybe String)
+#if defined(mingw32_HOST_OS)
+getExecPath =
+     allocaArray len $ \buf -> do
+         ret <- getModuleFileName nullPtr buf len
+         if ret == 0 then return Nothing
+	             else liftM Just $ peekCString buf
+    where len = 2048 -- Plenty, PATH_MAX is 512 under Win32.
+
+foreign import stdcall unsafe "GetModuleFileNameA"
+    getModuleFileName :: Ptr () -> CString -> Int -> IO Int32
+#else
+getExecPath = return Nothing
+#endif
