@@ -14,7 +14,7 @@ module Text.XML.HaXml.Parse
   , comment, cdsect, chardata
   , reference, doctypedecl
   , processinginstruction
-  , elemtag, name, tok
+  , elemtag, qname, name, tok
   , elemOpenTag, elemCloseTag
   , emptySTs, XParser
   -- * These general utility functions don't belong here
@@ -38,9 +38,12 @@ import Monad hiding (sequence)
 import Numeric (readDec,readHex)
 
 import Text.XML.HaXml.Types
+import Text.XML.HaXml.Namespaces
 import Text.XML.HaXml.Posn
 import Text.XML.HaXml.Lex
-import Text.ParserCombinators.Poly.NoLeak.State
+import Text.ParserCombinators.Poly.State
+
+import System.FilePath (combine, dropFileName)
 
 
 #if ( defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ > 502 ) || \
@@ -65,11 +68,11 @@ import IOExts(trace)
 #  elif defined(__NHC__) || defined(__HBC__)
 import NonStdTrace
 #  endif
-debug :: a -> String -> a
 v `debug` s = trace s v
 #else
 v `debug` s = v
 #endif
+debug :: a -> String -> a
 
 
 -- | To parse a whole document, @xmlParse file content@ takes a filename
@@ -101,6 +104,7 @@ dtdParse  name  = Prelude.either error id . dtdParse' name
 xmlParse' name  = fst3 . runParser (toEOF document) emptySTs . xmlLex name
 dtdParse' name  = fst3 . runParser justDTD  emptySTs . xmlLex name
 
+toEOF :: XParser a -> XParser a
 toEOF = id	-- there are other possible implementations...
 
 -- | To parse a partial document, e.g. from an XML-based stream protocol,
@@ -128,7 +132,7 @@ addGE :: String -> EntityDef -> SymTabs -> SymTabs
 addGE n v (pe,ge) = let newge = addST n v ge in newge `seq` (pe, newge)
 
 lookupPE :: String -> SymTabs -> Maybe PEDef
-lookupPE s (pe,ge) = lookupST s pe
+lookupPE s (pe,_ge) = lookupST s pe
 
 flattenEV :: EntityValue -> String
 flattenEV (EntityValue evs) = concatMap flatten evs
@@ -151,6 +155,13 @@ thd3 (_,_,a) = a
 
 ---- Auxiliary Parsing Functions ----
 
+-- | Parse a bracketed item, discarding the brackets AND NOT using adjustErrBad
+myBracket :: PolyParse p => p bra -> p ket -> p a -> p a
+myBracket open close p = do
+    do { open    `adjustErr` ("Missing opening bracket:\n\t"++)
+       ; p `discard` (close `adjustErr` ("Missing closing bracket:\n\t"++))
+       }
+
 -- | XParser is just a specialisation of the PolyState parser.
 type XParser a = Parser SymTabs (Posn,TokenT) a
 
@@ -165,6 +176,11 @@ nottok ts = do (p,t) <- next
                if t`elem`ts then report fail ("no "++show t) p t
                             else return t
 
+-- | Return a qualified name (although the namespace qualification is not
+--   processed here; this is merely to get the correct type).
+qname :: XParser QName
+qname = fmap N name
+
 -- | Return just a name, e.g. element name, attribute name.
 name :: XParser Name
 name = do (p,tok) <- next
@@ -194,12 +210,13 @@ either p q =
 word :: String -> XParser ()
 word s = do { x <- next
             ; case x of
-                (p,TokName n)     | s==n -> return ()
-                (p,TokFreeText n) | s==n -> return ()
-                (p,t@(TokError _)) -> report failBad (show s) p t
-                (p,t) -> report fail (show s) p t
+                (_p,TokName n)     | s==n -> return ()
+                (_p,TokFreeText n) | s==n -> return ()
+                ( p,t@(TokError _)) -> report failBad (show s) p t
+                ( p,t) -> report fail (show s) p t
             }
 
+posn :: XParser Posn
 posn = do { x@(p,_) <- next
           ; reparse [x]
           ; return p
@@ -213,8 +230,8 @@ failP msg = do { p <- posn; fail (msg++"\n    at "++show p) }
 failBadP msg = do { p <- posn; failBad (msg++"\n    at "++show p) }
 
 report :: (String->XParser a) -> String -> Posn -> TokenT -> XParser a
-report fail exp p t = fail ("Expected "++exp++" but found "++show t
-                           ++"\n  in "++show p)
+report fail expect p t = fail ("Expected "++expect++" but found "++show t
+                               ++"\n  in "++show p)
 
 adjustErrP :: XParser a -> (String->String) -> XParser a
 p `adjustErrP` f = p `onFail` do pn <- posn
@@ -234,16 +251,18 @@ peRef p =
                                `debug` ("  defn:  "++flattenEV ev)
                          peRef p
            Just (PEDefExternalID (PUBLIC _ (SystemLiteral f))) ->
-                      do let val = unsafePerformIO (readFile f)
-                         reparse (xmlReLex (posInNewCxt ("file "++f)
+                      do let f' = combine (dropFileName $ posnFilename pn) f
+                             val = unsafePerformIO (readFile f')
+                         reparse (xmlReLex (posInNewCxt f'
                                                         (Just pn)) val)
-                               `debug` ("  reading from file "++f)
+                               `debug` ("  reading from file "++f')
                          peRef p
            Just (PEDefExternalID (SYSTEM (SystemLiteral f))) ->
-                      do let val = unsafePerformIO (readFile f)
-                         reparse (xmlReLex (posInNewCxt ("file "++f)
+                      do let f' = combine (dropFileName $ posnFilename pn) f
+                             val = unsafePerformIO (readFile f')
+                         reparse (xmlReLex (posInNewCxt f'
                                                         (Just pn)) val)
-                               `debug` ("  reading from file "++f)
+                               `debug` ("  reading from file "++f')
                          peRef p
            Nothing -> fail ("PEReference use before definition: "++"%"++n++";"
                            ++"\n    at "++show pn)
@@ -268,13 +287,13 @@ justDTD :: XParser (Maybe DocTypeDecl)
 justDTD =
   do (ExtSubset _ ds) <- extsubset `debug` "Trying external subset"
      if null ds then fail "empty"
-         else return (Just (DTD "extsubset" Nothing (concatMap extract ds)))
+         else return (Just (DTD (N "extsubset") Nothing (concatMap extract ds)))
   `onFail`
   do (Prolog _ _ dtd _) <- prolog
      return dtd
  where extract (ExtMarkupDecl m) = [m]
        extract (ExtConditionalSect (IncludeSect i)) = concatMap extract i
-       extract (ExtConditionalSect (IgnoreSect i)) = []
+       extract (ExtConditionalSect (IgnoreSect _i)) = []
 
 -- | Return an entire XML document including prolog and trailing junk.
 document :: XParser (Document Posn)
@@ -288,7 +307,7 @@ document = do
 -- | Return an XML comment.
 comment :: XParser Comment
 comment = do
-    bracket (tok TokCommentOpen) (tok TokCommentClose) freetext
+    myBracket (tok TokCommentOpen) (tok TokCommentClose) freetext
 --  tok TokCommentOpen
 --  commit $ do
 --    c <- freetext
@@ -353,7 +372,7 @@ doctypedecl = do
     tok TokSpecialOpen
     tok (TokSpecial DOCTYPEx)
     commit $ do
-      n   <- name
+      n   <- qname
       eid <- maybe externalid
       es  <- maybe (bracket (tok TokSqOpen) (tok TokSqClose)
                             (many (peRef markupdecl)))
@@ -406,7 +425,7 @@ element = do
              ,  do tok TokAnyClose
                    cs <- many content
                    p  <- posn
-                   m  <- bracket (tok TokEndOpen) (tok TokAnyClose) name
+                   m  <- bracket (tok TokEndOpen) (tok TokAnyClose) qname
                    checkmatch p n m
                    return (Elem n as cs))
            ] `adjustErr` (("in element tag "++n++",\n")++)
@@ -426,19 +445,20 @@ element = do
                  manyFinally content
                              (do p <- posn
                                  m <- bracket (tok TokEndOpen)
-                                              (tok TokAnyClose) name
+                                              (tok TokAnyClose) qname
                                  checkmatch p n m)
-      ) `adjustErrBad` (("in element tag "++n++",\n")++)
+      ) `adjustErrBad` (("in element tag "++printableName n++",\n")++)
 
-checkmatch :: Posn -> Name -> Name -> XParser ()
+checkmatch :: Posn -> QName -> QName -> XParser ()
 checkmatch p n m =
   if n == m then return ()
-  else failBadP ("tag <"++n++"> terminated by </"++m++">")
+  else failBad ("tag <"++printableName n++"> terminated by </"++printableName m
+                ++">\n  at "++show p)
 
 -- | Parse only the parts between angle brackets in an element tag.
 elemtag :: XParser ElemTag
 elemtag = do
-    n  <- name `adjustErrBad` ("malformed element tag\n"++)
+    n  <- qname `adjustErrBad` ("malformed element tag\n"++)
     as <- many attribute
     return (ElemTag n as)
 
@@ -452,17 +472,17 @@ elemOpenTag = do
 
 -- | For use with stream parsers - accepts a closing tag, provided it
 --   matches the given element name.
-elemCloseTag :: Name -> XParser ()
+elemCloseTag :: QName -> XParser ()
 elemCloseTag n = do
     tok TokEndOpen
     p <- posn
-    m <- name
+    m <- qname
     tok TokAnyClose
     checkmatch p n m
 
 attribute :: XParser Attribute
 attribute = do
-    n <- name `adjustErr` ("malformed attribute name\n"++)
+    n <- qname `adjustErr` ("malformed attribute name\n"++)
     tok TokEqual `onFail` failBadP "missing = in attribute"
     v <- attvalue `onFail` failBadP "missing attvalue"
     return (n,v)
@@ -488,12 +508,13 @@ elementdecl :: XParser ElementDecl
 elementdecl = do
     tok TokSpecialOpen
     tok (TokSpecial ELEMENTx)
-    n <- peRef name `adjustErrBad` ("expecting identifier in ELEMENT decl\n"++)
+    n <- peRef qname `adjustErrBad` ("expecting identifier in ELEMENT decl\n"++)
     c <- peRef contentspec
-             `adjustErrBad` (("in content spec of ELEMENT decl: "++n++"\n")++)
+             `adjustErrBad` (("in content spec of ELEMENT decl: "
+                              ++printableName n++"\n")++)
     blank (tok TokAnyClose) `onFail` failBadP
        ("expected > terminating ELEMENT decl"
-       ++"\n    element name was "++show n
+       ++"\n    element name was "++show (printableName n)
        ++"\n    contentspec was "++(\ (ContentSpec p)-> show p) c)
     return (ElementDecl n c)
 
@@ -509,22 +530,18 @@ contentspec =
 
 choice :: XParser [CP]
 choice = do
-    bracket (tok TokBraOpen `debug` "Trying choice")
-            (blank (tok TokBraClose `debug` "Succeeded with choice"))
-            (peRef cp `sepBy1` blank (tok TokPipe))
+    myBracket (tok TokBraOpen `debug` "Trying choice")
+              (blank (tok TokBraClose `debug` "Succeeded with choice"))
+              (peRef cp `sepBy1` blank (tok TokPipe))
 
 sequence :: XParser [CP]
-sequence = do	-- bracket is inappropriate because of inner failBad
- -- bracket (tok TokBraOpen `debug` "Trying sequence")
- --         (blank (tok TokBraClose `debug` "Succeeded with sequence"))
- --         (peRef cp `sepBy1` blank (tok TokComma))
-    tok TokBraOpen `debug` "Trying sequence"
-    cps <- peRef cp `sepBy1` blank (tok TokComma)
-    blank (tok TokBraClose `debug` "Succeeded with sequence")
-    return cps
+sequence = do
+ myBracket (tok TokBraOpen `debug` "Trying sequence")
+           (blank (tok TokBraClose `debug` "Succeeded with sequence"))
+           (peRef cp `sepBy1` blank (tok TokComma))
 
 cp :: XParser CP
-cp = oneOf [ ( do n <- name
+cp = oneOf [ ( do n <- qname
                   m <- modifier
                   let c = TagName n m
                   return c `debug` ("ContentSpec: name "++show c))
@@ -547,7 +564,7 @@ modifier = oneOf [ ( tok TokStar >> return Star )
 
 -- just for debugging
 instance Show CP where
-    show (TagName n m) = n++show m
+    show (TagName n m) = printableName n++show m
     show (Choice cps m) = '(': concat (intersperse "|" (map show cps))
                           ++")"++show m
     show (Seq cps m) = '(': concat (intersperse "," (map show cps))
@@ -566,7 +583,7 @@ mixed = do
               word "PCDATA")
     commit $
       oneOf [ ( do cs <- many (peRef (do tok TokPipe
-                                         peRef name))
+                                         peRef qname))
                    blank (tok TokBraClose >> tok TokStar)
                    return (PCDATAplus cs))
             , ( blank (tok TokBraClose >> tok TokStar) >> return PCDATA)
@@ -578,16 +595,18 @@ attlistdecl :: XParser AttListDecl
 attlistdecl = do
     tok TokSpecialOpen
     tok (TokSpecial ATTLISTx)
-    n <- peRef name `adjustErrBad` ("expecting identifier in ATTLIST\n"++)
+    n <- peRef qname `adjustErrBad` ("expecting identifier in ATTLIST\n"++)
     ds <- peRef (many1 (peRef attdef))
     blank (tok TokAnyClose) `onFail` failBadP "missing > terminating ATTLIST"
     return (AttListDecl n ds)
 
 attdef :: XParser AttDef
 attdef =
-  do n <- peRef name `adjustErr` ("expecting attribute name\n"++)
-     t <- peRef atttype `adjustErr` (("within attlist defn: "++n++",\n")++)
-     d <- peRef defaultdecl `adjustErr` (("in attlist defn: "++n++",\n")++)
+  do n <- peRef qname `adjustErr` ("expecting attribute name\n"++)
+     t <- peRef atttype `adjustErr` (("within attlist defn: "
+                                     ++printableName n++",\n")++)
+     d <- peRef defaultdecl `adjustErr` (("in attlist defn: "
+                                         ++printableName n++",\n")++)
      return (AttDef n t d)
 
 atttype :: XParser AttType
@@ -614,8 +633,6 @@ tokenizedtype =
                ++" (ID, IDREF, IDREFS, ENTITY, ENTITIES, NMTOKEN, NMTOKENS)"
                ++"\nbut got "++show t)
        }
--- `adjustErr` (++"\nLooking for a tokenized type:\n\ 
--- \    (ID, IDREF, IDREFS, ENTITY, ENTITIES, NMTOKEN, NMTOKENS)")
 
 enumeratedtype :: XParser EnumeratedType
 enumeratedtype =
@@ -645,8 +662,6 @@ defaultdecl =
                               return (DefaultTo a f) )
            ]
         `adjustErr` ("looking for an attribute default decl,\n"++)
---      `adjustErr` (++"\nLooking for an attribute default decl:\n\ 
--- \    (REQUIRED, IMPLIED, FIXED)")
 
 conditionalsect :: XParser ConditionalSect
 conditionalsect = oneOf'
@@ -665,7 +680,7 @@ conditionalsect = oneOf'
            peRef (tok (TokSection IGNOREx))
            p <- posn
            tok TokSqOpen `onFail` failBadP "missing [ after IGNORE"
-           i <- many newIgnore  -- many ignoresectcontents
+           many newIgnore  -- many ignoresectcontents
            tok TokSectionClose
                    `onFail` failBadP ("missing ]]> for IGNORE section"
                                      ++"\n    begun at "++show p)
@@ -682,26 +697,26 @@ newIgnore =
          return Ignore  `debug` ("ignoring: "++show t))
 
 --- obsolete?
-ignoresectcontents :: XParser IgnoreSectContents
-ignoresectcontents = do
-    i <- ignore
-    is <- many (do tok TokSectionOpen
-                   ic <- ignoresectcontents
-                   tok TokSectionClose
-                   ig <- ignore
-                   return (ic,ig))
-    return (IgnoreSectContents i is)
-
-ignore :: XParser Ignore
-ignore = do
-  is <- many1 (nottok [TokSectionOpen,TokSectionClose])
-  return Ignore  `debug` ("ignored all of: "++show is)
+--ignoresectcontents :: XParser IgnoreSectContents
+--ignoresectcontents = do
+--    i <- ignore
+--    is <- many (do tok TokSectionOpen
+--                   ic <- ignoresectcontents
+--                   tok TokSectionClose
+--                   ig <- ignore
+--                   return (ic,ig))
+--    return (IgnoreSectContents i is)
+--
+--ignore :: XParser Ignore
+--ignore = do
+--  is <- many1 (nottok [TokSectionOpen,TokSectionClose])
+--  return Ignore  `debug` ("ignored all of: "++show is)
 ----
 
 -- | Return either a general entity reference, or a character reference.
 reference :: XParser Reference
 reference = do
-    bracket (tok TokAmp) (tok TokSemi) (freetext >>= val)
+    myBracket (tok TokAmp) (tok TokSemi) (freetext >>= val)
   where
     val ('#':'x':i) | all isHexDigit i
                     = return . RefChar . fst . head . readHex $ i
@@ -729,11 +744,7 @@ charref = do
 
 pereference :: XParser PEReference
 pereference = do
---  bracket (tok TokPercent) (tok TokSemi) nmtoken
-    tok TokPercent
-    p <- nmtoken
-    tok TokSemi
-    return p
+    myBracket (tok TokPercent) (tok TokSemi) nmtoken
 
 entitydecl :: XParser EntityDecl
 entitydecl =
@@ -802,17 +813,17 @@ textdecl = do
     tok TokPIClose `onFail` failP "expected ?> terminating text decl"
     return (TextDecl v e)
 
-extparsedent :: XParser (ExtParsedEnt Posn)
-extparsedent = do
-    t <- maybe textdecl
-    c <- content
-    return (ExtParsedEnt t c)
-
-extpe :: XParser ExtPE
-extpe = do
-    t <- maybe textdecl
-    e <- many (peRef extsubsetdecl)
-    return (ExtPE t e)
+--extparsedent :: XParser (ExtParsedEnt Posn)
+--extparsedent = do
+--    t <- maybe textdecl
+--    c <- content
+--    return (ExtParsedEnt t c)
+--
+--extpe :: XParser ExtPE
+--extpe = do
+--    t <- maybe textdecl
+--    e <- many (peRef extsubsetdecl)
+--    return (ExtPE t e)
 
 encodingdecl :: XParser EncodingDecl
 encodingdecl = do
