@@ -1,15 +1,13 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v207	((void*)startLabel+32)
-#define CT_v209	((void*)startLabel+104)
-#define FN_Debug_46Trace_46traceShow	((void*)startLabel+144)
-#define CT_v211	((void*)startLabel+172)
-#define F0_Debug_46Trace_46traceShow	((void*)startLabel+180)
-#define ST_v205	((void*)startLabel+196)
-#define ST_v206	((void*)startLabel+208)
-#define ST_v208	((void*)startLabel+232)
-#define ST_v210	((void*)startLabel+250)
+#define CT_v214	((void*)startLabel+32)
+#define CT_v216	((void*)startLabel+104)
+#define CT_v218	((void*)startLabel+172)
+#define ST_v212	((void*)startLabel+196)
+#define ST_v213	((void*)startLabel+208)
+#define ST_v215	((void*)startLabel+232)
+#define ST_v217	((void*)startLabel+250)
 extern Node TM_Debug_46Trace[];
 extern Node FN_IO_46hPutStrLn[];
 extern Node CF_IO_46stderr[];
@@ -22,16 +20,16 @@ extern Node FN_Prelude_46_46[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v207)
+, useLabel(CT_v214)
 ,};
 Node FN_Debug_46Trace_46putTraceMsg[] = {
   useLabel(TM_Debug_46Trace)
 , bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, 350001
-, useLabel(ST_v206)
-,	/* CT_v207: (byte 0) */
+, 360001
+, useLabel(ST_v213)
+,	/* CT_v214: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -41,7 +39,7 @@ Node F0_Debug_46Trace_46putTraceMsg[] = {
 , useLabel(CF_IO_46stderr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v209)
+, useLabel(CT_v216)
 ,};
 Node FN_Debug_46Trace_46trace[] = {
   useLabel(TM_Debug_46Trace)
@@ -52,9 +50,9 @@ Node FN_Debug_46Trace_46trace[] = {
 , bytes2word(7,HEAP_OFF_N1,5,RETURN_EVAL)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
-, 570001
-, useLabel(ST_v208)
-,	/* CT_v209: (byte 0) */
+, 600001
+, useLabel(ST_v215)
+,	/* CT_v216: (byte 0) */
   HW(5,2)
 , 0
 ,};
@@ -66,42 +64,44 @@ Node F0_Debug_46Trace_46trace[] = {
 , VAPTAG(useLabel(FN_Prelude_46_36))
 , useLabel(F0_NHC_46Internal_46unsafePerformIO)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v211)
-,	/* FN_Debug_46Trace_46traceShow: (byte 0) */
+, useLabel(CT_v218)
+,};
+Node FN_Debug_46Trace_46traceShow[] = {
   useLabel(TM_Debug_46Trace)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_OFF_N1)
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 670001
-, useLabel(ST_v210)
-,	/* CT_v211: (byte 0) */
+, 700001
+, useLabel(ST_v217)
+,	/* CT_v218: (byte 0) */
   HW(3,1)
 , 0
-,	/* F0_Debug_46Trace_46traceShow: (byte 0) */
+,};
+Node F0_Debug_46Trace_46traceShow[] = {
   CAPTAG(useLabel(FN_Debug_46Trace_46traceShow),1)
 , VAPTAG(useLabel(FN_Prelude_46show))
 , VAPTAG(useLabel(FN_Prelude_46_46))
 , useLabel(F0_Debug_46Trace_46trace)
 ,};
 Node PM_Debug_46Trace[] = {
- 	/* ST_v205: (byte 0) */
+ 	/* ST_v212: (byte 0) */
   bytes2word(68,101,98,117)
 , bytes2word(103,46,84,114)
-,	/* ST_v206: (byte 4) */
+,	/* ST_v213: (byte 4) */
   bytes2word(97,99,101,0)
 , bytes2word(68,101,98,117)
 , bytes2word(103,46,84,114)
 , bytes2word(97,99,101,46)
 , bytes2word(112,117,116,84)
 , bytes2word(114,97,99,101)
-,	/* ST_v208: (byte 4) */
+,	/* ST_v215: (byte 4) */
   bytes2word(77,115,103,0)
 , bytes2word(68,101,98,117)
 , bytes2word(103,46,84,114)
 , bytes2word(97,99,101,46)
 , bytes2word(116,114,97,99)
-,	/* ST_v210: (byte 2) */
+,	/* ST_v217: (byte 2) */
   bytes2word(101,0,68,101)
 , bytes2word(98,117,103,46)
 , bytes2word(84,114,97,99)
