@@ -15,9 +15,9 @@
 -----------------------------------------------------------------------------
 
 module System.CPUTime 
-	(
+        (
          getCPUTime,       -- :: IO Integer
-	 cpuTimePrecision  -- :: Integer
+         cpuTimePrecision  -- :: Integer
         ) where
 
 import Prelude
@@ -34,17 +34,26 @@ import CPUTime ( getCPUTime, cpuTimePrecision )
 # 32 "System/CPUTime.hsc"
 
 
-# 39 "System/CPUTime.hsc"
+# 67 "System/CPUTime.hsc"
 
 
-# 128 "System/CPUTime.hsc"
+# 69 "System/CPUTime.hsc"
+realToInteger :: Real a => a -> Integer
+realToInteger ct = round (realToFrac ct :: Double)
+  -- CTime, CClock, CUShort etc are in Real but not Fractional, 
+  -- so we must convert to Double before we can round it
+
+# 74 "System/CPUTime.hsc"
+
+
+# 161 "System/CPUTime.hsc"
 
 -- |The 'cpuTimePrecision' constant is the smallest measurable difference
 -- in CPU time that the implementation can record, and is given as an
 -- integral number of picoseconds.
 
 
-# 137 "System/CPUTime.hsc"
+# 170 "System/CPUTime.hsc"
 
 
-# 148 "System/CPUTime.hsc"
+# 181 "System/CPUTime.hsc"
