@@ -1,8 +1,12 @@
 {-# INCLUDE <time.h> #-}
 {-# OPTIONS_GHC -optc-DHAVE_TM_ZONE=1 #-}
 # 1 "System/Time.hsc"
------------------------------------------------------------------------------
+{-# OPTIONS_GHC -fno-warn-unused-binds #-}
 # 2 "System/Time.hsc"
+-- XXX with some combinations of #defines we get warnings, e.g.
+-- Warning: Defined but not used: `throwAwayReturnPointer'
+
+-----------------------------------------------------------------------------
 -- |
 -- Module      :  System.Time
 -- Copyright   :  (c) The University of Glasgow 2001
@@ -12,10 +16,15 @@
 -- Stability   :  provisional
 -- Portability :  portable
 --
--- The standard Time library, providing standard functionality for clock
--- times, including timezone information (i.e, the functionality of
--- \"@time.h@\", adapted to the Haskell environment).  It follows RFC
--- 1129 in its use of Coordinated Universal Time (UTC).
+-- The standard time library from Haskell 98.  This library is
+-- deprecated, please look at "Data.Time" in the @time@ package
+-- instead.
+--
+-- "System.Time" provides functionality for clock times, including
+-- timezone information (i.e, the functionality of \"@time.h@\",
+-- adapted to the Haskell environment).  It follows RFC 1129 in its
+-- use of Coordinated Universal Time (UTC).
+--
 -----------------------------------------------------------------------------
 
 {-
@@ -103,34 +112,33 @@ module System.Time
      ) where
 
 
-# 104 "System/Time.hsc"
+# 113 "System/Time.hsc"
 
 
-# 106 "System/Time.hsc"
+# 115 "System/Time.hsc"
 
-# 107 "System/Time.hsc"
+# 116 "System/Time.hsc"
 
-# 110 "System/Time.hsc"
+# 119 "System/Time.hsc"
 
-# 111 "System/Time.hsc"
+# 120 "System/Time.hsc"
 
-# 112 "System/Time.hsc"
+# 121 "System/Time.hsc"
 import Ix
 
-# 114 "System/Time.hsc"
+# 123 "System/Time.hsc"
 
 import Prelude
 
 import Data.Ix
 import System.Locale
-import System.IO.Unsafe
-
-
-# 124 "System/Time.hsc"
 import Foreign
+
+
+# 133 "System/Time.hsc"
 import Foreign.C
 
-# 127 "System/Time.hsc"
+# 135 "System/Time.hsc"
 
 -- One way to partition and give name to chunks of a year and a week:
 
@@ -183,7 +191,7 @@ min           0 .. 59
 sec           0 .. 61           [Allows for two leap seconds]
 picosec       0 .. (10^12)-1    [This could be over-precise?]
 yday          0 .. 365          [364 in non-Leap years]
-tz       -43200 .. 43200        [Variation from UTC in seconds]
+tz       -43200 .. 50400        [Variation from UTC in seconds]
 \end{verbatim}
 -}
 
@@ -232,16 +240,20 @@ noTimeDiff = TimeDiff 0 0 0 0 0 0 0
 -- -----------------------------------------------------------------------------
 -- | returns the current time in its internal representation.
 
+realToInteger :: Real a => a -> Integer
+realToInteger ct = round (realToFrac ct :: Double)
+  -- CTime, CClock, CUShort etc are in Real but not Fractional, 
+  -- so we must convert to Double before we can round it
+
 getClockTime :: IO ClockTime
 
-# 253 "System/Time.hsc"
+# 264 "System/Time.hsc"
 getClockTime = do
     secs <- time nullPtr -- can't fail, according to POSIX
-    let realToInteger = round . realToFrac :: Real a => a -> Integer
     return (TOD (realToInteger secs) 0)
 
 
-# 259 "System/Time.hsc"
+# 269 "System/Time.hsc"
 
 -- -----------------------------------------------------------------------------
 -- | @'addToClockTime' d t@ adds a time difference @d@ and a
@@ -249,11 +261,11 @@ getClockTime = do
 -- may be either positive or negative.
 
 addToClockTime  :: TimeDiff  -> ClockTime -> ClockTime
-addToClockTime (TimeDiff year mon day hour min sec psec) 
+addToClockTime (TimeDiff year mon day hour minute sec psec)
 	       (TOD c_sec c_psec) = 
 	let
 	  sec_diff = toInteger sec +
-                     60 * toInteger min +
+                     60 * toInteger minute +
                      3600 * toInteger hour +
                      24 * 3600 * toInteger day
           (d_sec, d_psec) = (c_psec + psec) `quotRem` 1000000000000
@@ -324,7 +336,7 @@ normalizeTimeDiff td =
         }
 
 
-# 341 "System/Time.hsc"
+# 351 "System/Time.hsc"
 -- -----------------------------------------------------------------------------
 -- How do we deal with timezones on this architecture?
 
@@ -335,16 +347,16 @@ normalizeTimeDiff td =
 zone   :: Ptr CTm -> IO (Ptr CChar)
 gmtoff :: Ptr CTm -> IO CLong
 
-# 351 "System/Time.hsc"
+# 361 "System/Time.hsc"
 zone x      = ((\hsc_ptr -> peekByteOff hsc_ptr 40)) x
-# 352 "System/Time.hsc"
+# 362 "System/Time.hsc"
 gmtoff x    = ((\hsc_ptr -> peekByteOff hsc_ptr 36)) x
-# 353 "System/Time.hsc"
+# 363 "System/Time.hsc"
 
 
-# 401 "System/Time.hsc"
+# 410 "System/Time.hsc"
 
-# 402 "System/Time.hsc"
+# 411 "System/Time.hsc"
 
 -- -----------------------------------------------------------------------------
 -- | converts an internal clock time to a local time, modified by the
@@ -354,29 +366,29 @@ gmtoff x    = ((\hsc_ptr -> peekByteOff hsc_ptr 36)) x
 
 toCalendarTime :: ClockTime -> IO CalendarTime
 
-# 415 "System/Time.hsc"
+# 424 "System/Time.hsc"
 toCalendarTime =  clockToCalendarTime_static localtime False
 
-# 417 "System/Time.hsc"
+# 426 "System/Time.hsc"
 
 -- | converts an internal clock time into a 'CalendarTime' in standard
 -- UTC format.
 
 toUTCTime :: ClockTime -> CalendarTime
 
-# 427 "System/Time.hsc"
+# 436 "System/Time.hsc"
 toUTCTime      =  unsafePerformIO . clockToCalendarTime_static gmtime True
 
-# 429 "System/Time.hsc"
+# 438 "System/Time.hsc"
 
 
-# 454 "System/Time.hsc"
+# 463 "System/Time.hsc"
 throwAwayReturnPointer :: (Ptr CTime -> Ptr CTm -> IO (Ptr CTm))
                        -> (Ptr CTime -> Ptr CTm -> IO (       ))
 throwAwayReturnPointer fun x y = fun x y >> return ()
 
 
-# 459 "System/Time.hsc"
+# 468 "System/Time.hsc"
 clockToCalendarTime_static :: (Ptr CTime -> IO (Ptr CTm)) -> Bool -> ClockTime
 	 -> IO CalendarTime
 clockToCalendarTime_static fun is_utc (TOD secs psec) = do
@@ -384,35 +396,35 @@ clockToCalendarTime_static fun is_utc (TOD secs psec) = do
     p_tm <- fun p_timer 	-- can't fail, according to POSIX
     clockToCalendarTime_aux is_utc p_tm psec
 
-# 466 "System/Time.hsc"
+# 475 "System/Time.hsc"
 
 
-# 476 "System/Time.hsc"
+# 485 "System/Time.hsc"
 
 clockToCalendarTime_aux :: Bool -> Ptr CTm -> Integer -> IO CalendarTime
 clockToCalendarTime_aux is_utc p_tm psec = do
     sec   <-  ((\hsc_ptr -> peekByteOff hsc_ptr 0)) p_tm :: IO CInt
-# 480 "System/Time.hsc"
-    min   <-  ((\hsc_ptr -> peekByteOff hsc_ptr 4)) p_tm :: IO CInt
-# 481 "System/Time.hsc"
+# 489 "System/Time.hsc"
+    minute <-  ((\hsc_ptr -> peekByteOff hsc_ptr 4)) p_tm :: IO CInt
+# 490 "System/Time.hsc"
     hour  <-  ((\hsc_ptr -> peekByteOff hsc_ptr 8)) p_tm :: IO CInt
-# 482 "System/Time.hsc"
+# 491 "System/Time.hsc"
     mday  <-  ((\hsc_ptr -> peekByteOff hsc_ptr 12)) p_tm :: IO CInt
-# 483 "System/Time.hsc"
+# 492 "System/Time.hsc"
     mon   <-  ((\hsc_ptr -> peekByteOff hsc_ptr 16)) p_tm :: IO CInt
-# 484 "System/Time.hsc"
+# 493 "System/Time.hsc"
     year  <-  ((\hsc_ptr -> peekByteOff hsc_ptr 20)) p_tm :: IO CInt
-# 485 "System/Time.hsc"
+# 494 "System/Time.hsc"
     wday  <-  ((\hsc_ptr -> peekByteOff hsc_ptr 24)) p_tm :: IO CInt
-# 486 "System/Time.hsc"
+# 495 "System/Time.hsc"
     yday  <-  ((\hsc_ptr -> peekByteOff hsc_ptr 28)) p_tm :: IO CInt
-# 487 "System/Time.hsc"
+# 496 "System/Time.hsc"
     isdst <-  ((\hsc_ptr -> peekByteOff hsc_ptr 32)) p_tm :: IO CInt
-# 488 "System/Time.hsc"
-    zone  <-  zone p_tm
+# 497 "System/Time.hsc"
+    zone' <-  zone p_tm
     tz    <-  gmtoff p_tm
     
-    tzname <- peekCString zone
+    tzname' <- peekCString zone'
     
     let month  | mon >= 0 && mon <= 11 = toEnum (fromIntegral mon)
     	       | otherwise             = error ("toCalendarTime: illegal month value: " ++ show mon)
@@ -422,16 +434,16 @@ clockToCalendarTime_aux is_utc p_tm psec = do
 		month
 		(fromIntegral mday)
 		(fromIntegral hour)
-		(fromIntegral min)
+		(fromIntegral minute)
 		(fromIntegral sec)
 		psec
             	(toEnum (fromIntegral wday))
 		(fromIntegral yday)
-		(if is_utc then "UTC" else tzname)
+		(if is_utc then "UTC" else tzname')
 		(if is_utc then 0     else fromIntegral tz)
 		(if is_utc then False else isdst /= 0))
 
-# 510 "System/Time.hsc"
+# 519 "System/Time.hsc"
 
 -- | converts a 'CalendarTime' into the corresponding internal
 -- 'ClockTime', ignoring the contents of the  'ctWDay', 'ctYDay',
@@ -439,39 +451,39 @@ clockToCalendarTime_aux is_utc p_tm psec = do
 
 toClockTime :: CalendarTime -> ClockTime
 
-# 523 "System/Time.hsc"
-toClockTime (CalendarTime year mon mday hour min sec psec 
-			  _wday _yday _tzname tz isdst) =
+# 532 "System/Time.hsc"
+toClockTime (CalendarTime year mon mday hour minute sec psec
+			  _wday _yday _tzname tz _isdst) =
 
      -- `isDst' causes the date to be wrong by one hour...
      -- FIXME: check, whether this works on other arch's than Linux, too...
      -- 
      -- so we set it to (-1) (means `unknown') and let `mktime' determine
      -- the real value...
-    let isDst = -1 :: CInt in   -- if isdst then (1::Int) else 0
+    let isDst = -1 :: CInt in   -- if _isdst then (1::Int) else 0
 
     if psec < 0 || psec > 999999999999 then
         error "Time.toClockTime: picoseconds out of range"
-    else if tz < -43200 || tz > 43200 then
+    else if tz < -43200 || tz > 50400 then
         error "Time.toClockTime: timezone offset out of range"
     else
       unsafePerformIO $ do
       allocaBytes (44) $ \ p_tm -> do
-# 540 "System/Time.hsc"
+# 549 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 0)) p_tm	(fromIntegral sec  :: CInt)
-# 541 "System/Time.hsc"
-        ((\hsc_ptr -> pokeByteOff hsc_ptr 4)) p_tm	(fromIntegral min  :: CInt)
-# 542 "System/Time.hsc"
+# 550 "System/Time.hsc"
+        ((\hsc_ptr -> pokeByteOff hsc_ptr 4)) p_tm	(fromIntegral minute :: CInt)
+# 551 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 8)) p_tm	(fromIntegral hour :: CInt)
-# 543 "System/Time.hsc"
+# 552 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 12)) p_tm	(fromIntegral mday :: CInt)
-# 544 "System/Time.hsc"
+# 553 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 16)) p_tm	(fromIntegral (fromEnum mon) :: CInt)
-# 545 "System/Time.hsc"
+# 554 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 20)) p_tm	(fromIntegral year - 1900 :: CInt)
-# 546 "System/Time.hsc"
+# 555 "System/Time.hsc"
         ((\hsc_ptr -> pokeByteOff hsc_ptr 32)) p_tm	isDst
-# 547 "System/Time.hsc"
+# 556 "System/Time.hsc"
 	t <- throwIf (== -1) (\_ -> "Time.toClockTime: invalid input")
 		(mktime p_tm)
         -- 
@@ -486,12 +498,11 @@ toClockTime (CalendarTime year mon mday hour min sec psec
         -- to compensate, we add the timezone difference to mktime's
         -- result.
         -- 
-        gmtoff <- gmtoff p_tm
-        let realToInteger = round . realToFrac :: Real a => a -> Integer
-	    res = realToInteger t - fromIntegral tz + fromIntegral gmtoff
+        gmtoffset <- gmtoff p_tm
+        let res = realToInteger t - fromIntegral tz + fromIntegral gmtoffset
 	return (TOD res psec)
 
-# 566 "System/Time.hsc"
+# 574 "System/Time.hsc"
 
 -- -----------------------------------------------------------------------------
 -- Converting time values to strings.
@@ -506,8 +517,8 @@ calendarTimeToString  =  formatCalendarTime defaultTimeLocale "%c"
 -- function.
 
 formatCalendarTime :: TimeLocale -> String -> CalendarTime -> String
-formatCalendarTime l fmt (CalendarTime year mon day hour min sec _
-                                       wday yday tzname _ _) =
+formatCalendarTime l fmt cal@(CalendarTime year mon day hour minute sec _
+                                       wday yday tzname' _ _) =
         doFmt fmt
   where doFmt ('%':'-':cs) = doFmt ('%':cs) -- padding not implemented
         doFmt ('%':'_':cs) = doFmt ('%':cs) -- padding not implemented
@@ -530,7 +541,7 @@ formatCalendarTime l fmt (CalendarTime year mon day hour min sec _
         decode 'j' = show3 yday                      -- day of the year
         decode 'k' = show2' hour                     -- hours, 24-hour clock, no padding
         decode 'l' = show2' (to12 hour)              -- hours, 12-hour clock, no padding
-        decode 'M' = show2 min                       -- minutes
+        decode 'M' = show2 minute                    -- minutes
         decode 'm' = show2 (fromEnum mon+1)          -- numeric month
         decode 'n' = "\n"
         decode 'p' = (if hour < 12 then fst else snd) (amPm l) -- am or pm
@@ -539,7 +550,8 @@ formatCalendarTime l fmt (CalendarTime year mon day hour min sec _
         decode 'T' = doFmt "%H:%M:%S"
         decode 't' = "\t"
         decode 'S' = show2 sec			     -- seconds
-        decode 's' = show2 sec			     -- number of secs since Epoch. (ToDo.)
+        decode 's' = let TOD esecs _ = toClockTime cal in show esecs
+                                                     -- number of secs since Epoch.
         decode 'U' = show2 ((yday + 7 - fromEnum wday) `div` 7) -- week number, starting on Sunday.
         decode 'u' = show (let n = fromEnum wday in  -- numeric day of the week (1=Monday, 7=Sunday)
                            if n == 0 then 7 else n)
@@ -559,7 +571,7 @@ formatCalendarTime l fmt (CalendarTime year mon day hour min sec _
         decode 'x' = doFmt (dateFmt l)               -- locale's preferred way of printing dates.
         decode 'Y' = show year                       -- year, including century.
         decode 'y' = show2 (year `rem` 100)          -- year, within century.
-        decode 'Z' = tzname                          -- timezone name
+        decode 'Z' = tzname'                         -- timezone name
         decode '%' = "%"
         decode c   = [c]
 
@@ -592,7 +604,7 @@ timeDiffToString = formatTimeDiff defaultTimeLocale "%c"
 -- function.
 
 formatTimeDiff :: TimeLocale -> String -> TimeDiff -> String
-formatTimeDiff l fmt td@(TimeDiff year month day hour min sec _)
+formatTimeDiff l fmt (TimeDiff year month day hour minute sec _)
  = doFmt fmt
   where 
    doFmt ""         = ""
@@ -606,7 +618,7 @@ formatTimeDiff l fmt td@(TimeDiff year month day hour min sec _)
       'B' -> fst (months l !! fromEnum month)
       'b' -> snd (months l !! fromEnum month)
       'h' -> snd (months l !! fromEnum month)
-      'c' -> defaultTimeDiffFmt td
+      'c' -> defaultTimeDiffFmt
       'C' -> show2 (year `quot` 100)
       'D' -> doFmt "%m/%d/%y"
       'd' -> show2 day
@@ -615,7 +627,7 @@ formatTimeDiff l fmt td@(TimeDiff year month day hour min sec _)
       'I' -> show2 (to12 hour)
       'k' -> show2' hour
       'l' -> show2' (to12 hour)
-      'M' -> show2 min
+      'M' -> show2 minute
       'm' -> show2 (fromEnum month + 1)
       'n' -> "\n"
       'p' -> (if hour < 12 then fst else snd) (amPm l)
@@ -632,7 +644,7 @@ formatTimeDiff l fmt td@(TimeDiff year month day hour min sec _)
       '%' -> "%"
       c   -> [c]
 
-   defaultTimeDiffFmt (TimeDiff year month day hour min sec _) =
+   defaultTimeDiffFmt =
        foldr (\ (v,s) rest -> 
                   (if v /= 0 
                      then show v ++ ' ':(addS v s)
@@ -640,36 +652,36 @@ formatTimeDiff l fmt td@(TimeDiff year month day hour min sec _)
                      else "") ++ rest
              )
              ""
-             (zip [year, month, day, hour, min, sec] (intervals l))
+             (zip [year, month, day, hour, minute, sec] (intervals l))
 
    addS v s = if abs v == 1 then fst s else snd s
 
 
-# 719 "System/Time.hsc"
+# 728 "System/Time.hsc"
 -- -----------------------------------------------------------------------------
 -- Foreign time interface (POSIX)
 
 type CTm = () -- struct tm
 
 
-# 728 "System/Time.hsc"
+# 737 "System/Time.hsc"
 foreign import ccall unsafe "time.h localtime"
     localtime   :: Ptr CTime -> IO (Ptr CTm)
 
-# 731 "System/Time.hsc"
+# 740 "System/Time.hsc"
 
-# 735 "System/Time.hsc"
+# 744 "System/Time.hsc"
 foreign import ccall unsafe "time.h gmtime"
     gmtime      :: Ptr CTime -> IO (Ptr CTm)
 
-# 738 "System/Time.hsc"
+# 747 "System/Time.hsc"
 foreign import ccall unsafe "time.h mktime"
     mktime      :: Ptr CTm   -> IO CTime
 
 
-# 754 "System/Time.hsc"
+# 763 "System/Time.hsc"
 foreign import ccall unsafe "time.h time" time :: Ptr CTime -> IO CTime
 
-# 756 "System/Time.hsc"
+# 765 "System/Time.hsc"
 
-# 757 "System/Time.hsc"
+# 766 "System/Time.hsc"
