@@ -29,7 +29,7 @@ module NHC.IOExtras
 
 
 import FixIO
-import NHC.Internal (unsafePerformIO)
+import NHC.Internal (unsafePerformIO,unsafeInterleaveIO)
 import Ix
 
 import DIORef
@@ -53,8 +53,3 @@ import ExcludeFinalisers
 
 import HPutGetBuf
 
-nyi f = trace ("IOExtras."++f++": not implemented")
-
-unsafeInterleaveIO :: IO a -> IO a
-unsafeInterleaveIO = nyi "unsafeInterleaveIO"
-
