@@ -1,103 +1,64 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define FN_Prelude_46cDIsNeg	((void*)startLabel+8)
-#define CT_v331	((void*)startLabel+32)
-#define F0_Prelude_46cDIsNeg	((void*)startLabel+40)
-#define FN_Prelude_46cDIsNormal	((void*)startLabel+68)
-#define CT_v334	((void*)startLabel+92)
-#define F0_Prelude_46cDIsNormal	((void*)startLabel+100)
-#define FN_Prelude_46cDIsFinite	((void*)startLabel+128)
-#define CT_v337	((void*)startLabel+152)
-#define F0_Prelude_46cDIsFinite	((void*)startLabel+160)
-#define FN_Prelude_46cDIsNaN	((void*)startLabel+188)
-#define CT_v340	((void*)startLabel+212)
-#define F0_Prelude_46cDIsNaN	((void*)startLabel+220)
-#define CT_v344	((void*)startLabel+312)
-#define CT_v350	((void*)startLabel+484)
-#define CT_v355	((void*)startLabel+608)
-#define CT_v360	((void*)startLabel+728)
-#define CT_v364	((void*)startLabel+824)
-#define CT_v368	((void*)startLabel+920)
-#define CT_v372	((void*)startLabel+1012)
-#define CT_v376	((void*)startLabel+1168)
-#define CT_v379	((void*)startLabel+1224)
-#define CT_v382	((void*)startLabel+1304)
-#define CT_v386	((void*)startLabel+1396)
-#define CT_v390	((void*)startLabel+1496)
-#define CT_v394	((void*)startLabel+1592)
-#define CT_v398	((void*)startLabel+1688)
-#define CT_v402	((void*)startLabel+1828)
-#define ST_v400	((void*)startLabel+1920)
-#define ST_v384	((void*)startLabel+1956)
-#define ST_v370	((void*)startLabel+1996)
-#define ST_v366	((void*)startLabel+2044)
-#define ST_v396	((void*)startLabel+2092)
-#define ST_v378	((void*)startLabel+2136)
-#define ST_v381	((void*)startLabel+2184)
-#define ST_v374	((void*)startLabel+2228)
-#define ST_v352	((void*)startLabel+2272)
-#define ST_v342	((void*)startLabel+2320)
-#define ST_v357	((void*)startLabel+2360)
-#define ST_v362	((void*)startLabel+2404)
-#define ST_v346	((void*)startLabel+2444)
-#define ST_v388	((void*)startLabel+2492)
-#define ST_v392	((void*)startLabel+2536)
-#define PP_Prelude_46cDIsFinite	((void*)startLabel+2581)
-#define PC_Prelude_46cDIsFinite	((void*)startLabel+2581)
-#define ST_v336	((void*)startLabel+2581)
-#define PP_Prelude_46cDIsNaN	((void*)startLabel+2600)
-#define PC_Prelude_46cDIsNaN	((void*)startLabel+2600)
-#define ST_v339	((void*)startLabel+2600)
-#define PP_Prelude_46cDIsNeg	((void*)startLabel+2616)
-#define PC_Prelude_46cDIsNeg	((void*)startLabel+2616)
-#define ST_v330	((void*)startLabel+2616)
-#define PP_Prelude_46cDIsNormal	((void*)startLabel+2632)
-#define PC_Prelude_46cDIsNormal	((void*)startLabel+2632)
-#define ST_v333	((void*)startLabel+2632)
-#define PS_v338	((void*)startLabel+2652)
-#define PS_v335	((void*)startLabel+2664)
-#define PS_v332	((void*)startLabel+2676)
-#define PS_v329	((void*)startLabel+2688)
-#define PS_v380	((void*)startLabel+2700)
-#define PS_v377	((void*)startLabel+2712)
-#define PS_v375	((void*)startLabel+2724)
-#define PS_v373	((void*)startLabel+2736)
-#define PS_v371	((void*)startLabel+2748)
-#define PS_v369	((void*)startLabel+2760)
-#define PS_v367	((void*)startLabel+2772)
-#define PS_v365	((void*)startLabel+2784)
-#define PS_v363	((void*)startLabel+2796)
-#define PS_v361	((void*)startLabel+2808)
-#define PS_v359	((void*)startLabel+2820)
-#define PS_v358	((void*)startLabel+2832)
-#define PS_v356	((void*)startLabel+2844)
-#define PS_v354	((void*)startLabel+2856)
-#define PS_v353	((void*)startLabel+2868)
-#define PS_v351	((void*)startLabel+2880)
-#define PS_v349	((void*)startLabel+2892)
-#define PS_v347	((void*)startLabel+2904)
-#define PS_v345	((void*)startLabel+2916)
-#define PS_v348	((void*)startLabel+2928)
-#define PS_v343	((void*)startLabel+2940)
-#define PS_v341	((void*)startLabel+2952)
-#define PS_v397	((void*)startLabel+2964)
-#define PS_v395	((void*)startLabel+2976)
-#define PS_v393	((void*)startLabel+2988)
-#define PS_v391	((void*)startLabel+3000)
-#define PS_v389	((void*)startLabel+3012)
-#define PS_v387	((void*)startLabel+3024)
-#define PS_v385	((void*)startLabel+3036)
-#define PS_v383	((void*)startLabel+3048)
-#define PS_v399	((void*)startLabel+3060)
-#define PS_v401	((void*)startLabel+3072)
-void FR_Prelude_46cDIsNeg(void);
-void FR_Prelude_46cDIsNormal(void);
-void FR_Prelude_46cDIsFinite(void);
-void FR_Prelude_46cDIsNaN(void);
-extern Node FN_Prelude_46Eq_46Prelude_46Double_46_61_61[];
-extern Node FN_Prelude_46_38_38[];
-extern Node FN_Prelude_46not[];
+#define CT_v308	((void*)startLabel+72)
+#define CT_v312	((void*)startLabel+172)
+#define CT_v316	((void*)startLabel+272)
+#define CT_v320	((void*)startLabel+372)
+#define CT_v324	((void*)startLabel+472)
+#define CT_v328	((void*)startLabel+564)
+#define CT_v332	((void*)startLabel+656)
+#define CT_v336	((void*)startLabel+812)
+#define CT_v339	((void*)startLabel+868)
+#define CT_v342	((void*)startLabel+948)
+#define CT_v346	((void*)startLabel+1040)
+#define CT_v350	((void*)startLabel+1140)
+#define CT_v354	((void*)startLabel+1236)
+#define CT_v358	((void*)startLabel+1332)
+#define CT_v362	((void*)startLabel+1472)
+#define ST_v360	((void*)startLabel+1564)
+#define ST_v344	((void*)startLabel+1600)
+#define ST_v330	((void*)startLabel+1640)
+#define ST_v326	((void*)startLabel+1688)
+#define ST_v356	((void*)startLabel+1736)
+#define ST_v338	((void*)startLabel+1780)
+#define ST_v341	((void*)startLabel+1828)
+#define ST_v334	((void*)startLabel+1872)
+#define ST_v314	((void*)startLabel+1916)
+#define ST_v306	((void*)startLabel+1964)
+#define ST_v318	((void*)startLabel+2004)
+#define ST_v322	((void*)startLabel+2048)
+#define ST_v310	((void*)startLabel+2088)
+#define ST_v348	((void*)startLabel+2136)
+#define ST_v352	((void*)startLabel+2180)
+#define PS_v340	((void*)startLabel+2228)
+#define PS_v337	((void*)startLabel+2240)
+#define PS_v335	((void*)startLabel+2252)
+#define PS_v333	((void*)startLabel+2264)
+#define PS_v331	((void*)startLabel+2276)
+#define PS_v329	((void*)startLabel+2288)
+#define PS_v327	((void*)startLabel+2300)
+#define PS_v325	((void*)startLabel+2312)
+#define PS_v323	((void*)startLabel+2324)
+#define PS_v321	((void*)startLabel+2336)
+#define PS_v319	((void*)startLabel+2348)
+#define PS_v317	((void*)startLabel+2360)
+#define PS_v315	((void*)startLabel+2372)
+#define PS_v313	((void*)startLabel+2384)
+#define PS_v311	((void*)startLabel+2396)
+#define PS_v309	((void*)startLabel+2408)
+#define PS_v307	((void*)startLabel+2420)
+#define PS_v305	((void*)startLabel+2432)
+#define PS_v357	((void*)startLabel+2444)
+#define PS_v355	((void*)startLabel+2456)
+#define PS_v353	((void*)startLabel+2468)
+#define PS_v351	((void*)startLabel+2480)
+#define PS_v349	((void*)startLabel+2492)
+#define PS_v347	((void*)startLabel+2504)
+#define PS_v345	((void*)startLabel+2516)
+#define PS_v343	((void*)startLabel+2528)
+#define PS_v359	((void*)startLabel+2540)
+#define PS_v361	((void*)startLabel+2552)
 extern Node FN_Prelude_46primEncodeDouble[];
 extern Node FN_Prelude_46primDecodeDouble[];
 extern Node FN_Prelude_46_95_46atan2[];
@@ -111,10 +72,7 @@ extern Node PM_Prelude[];
 extern Node PC_Prelude_462[];
 extern Node PC_Prelude_46primDecodeDouble[];
 extern Node PC_Prelude_46primEncodeDouble[];
-extern Node PC_Prelude_46not[];
-extern Node PC_Prelude_46_38_38[];
-extern Node PC_Prelude_46Eq_46Prelude_46Double_46_61_61[];
-extern Node PC_Prelude_46True[];
+extern Node PC_Prelude_46False[];
 extern Node PC_Prelude_46_95_46exponent[];
 extern Node PC_Prelude_46_95_46significand[];
 extern Node PC_Prelude_46_95_46scaleFloat[];
@@ -123,259 +81,158 @@ extern Node PC_Prelude_4616[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v331)
-,	/* FN_Prelude_46cDIsNeg: (byte 0) */
-  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNeg)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 270001
-, useLabel(ST_v330)
-,	/* CT_v331: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNeg: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNeg),1)
-, useLabel(PS_v329)
-, 0
-, 0
-, 0
-, bytes2word(1,0,0,1)
-, useLabel(CT_v334)
-,	/* FN_Prelude_46cDIsNormal: (byte 0) */
-  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNormal)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 260001
-, useLabel(ST_v333)
-,	/* CT_v334: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNormal: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNormal),1)
-, useLabel(PS_v332)
-, 0
-, 0
-, 0
-, bytes2word(1,0,0,1)
-, useLabel(CT_v337)
-,	/* FN_Prelude_46cDIsFinite: (byte 0) */
-  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsFinite)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 250001
-, useLabel(ST_v336)
-,	/* CT_v337: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsFinite: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsFinite),1)
-, useLabel(PS_v335)
-, 0
-, 0
-, 0
-, bytes2word(1,0,0,1)
-, useLabel(CT_v340)
-,	/* FN_Prelude_46cDIsNaN: (byte 0) */
-  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNaN)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 240001
-, useLabel(ST_v339)
-,	/* CT_v340: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNaN: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNaN),1)
-, useLabel(PS_v338)
-, 0
-, 0
-, 0
-, bytes2word(1,0,0,1)
-, useLabel(CT_v344)
+, useLabel(CT_v308)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
   bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
 , bytes2word(7,HEAP_CVAL_N1,12,HEAP_CREATE)
 , bytes2word(HEAP_SPACE,HEAP_SPACE,RETURN,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v343)
+, useLabel(PS_v307)
 , 0
 , 0
 , 0
 , 0
-, CONSTR(1,0,0)
+, CONSTR(0,0,0)
 , 0
 , 0
 , 0
 , 0
 , 220005
-, useLabel(ST_v342)
-,	/* CT_v344: (byte 0) */
+, useLabel(ST_v306)
+,	/* CT_v308: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isIEEE),1)
-, useLabel(PS_v341)
+, useLabel(PS_v305)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v350)
+, useLabel(CT_v312)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
-  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
-, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
-, bytes2word(HEAP_ARG,1,HEAP_CVAL_P1,8)
-, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
-, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CADR_N1)
-, bytes2word(19,PUSH_HEAP,HEAP_CVAL_P1,9)
-, bytes2word(HEAP_CVAL_N1,24,HEAP_CREATE,HEAP_SPACE)
-, bytes2word(HEAP_SPACE,HEAP_OFF_N1,18,HEAP_OFF_N1)
-, bytes2word(13,RETURN_EVAL,ENDCODE,0)
+  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
+, bytes2word(7,HEAP_CVAL_N1,12,HEAP_CREATE)
+, bytes2word(HEAP_SPACE,HEAP_SPACE,RETURN,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v349)
+, useLabel(PS_v311)
 , 0
 , 0
 , 0
 , 0
-, CONSTRW(2,0)
-, 0
-, 0
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v348)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v347)
+, CONSTR(0,0,0)
 , 0
 , 0
 , 0
 , 0
 , 210005
-, useLabel(ST_v346)
-,	/* CT_v350: (byte 0) */
-  HW(3,1)
+, useLabel(ST_v310)
+,	/* CT_v312: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero),1)
-, useLabel(PS_v345)
+, useLabel(PS_v309)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_Prelude_46cDIsNeg))
-, VAPTAG(useLabel(FN_Prelude_46Eq_46Prelude_46Double_46_61_61))
-, VAPTAG(useLabel(FN_Prelude_46_38_38))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v355)
+, useLabel(CT_v316)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
-  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
-, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
-, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
-, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
-, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
+, bytes2word(7,HEAP_CVAL_N1,12,HEAP_CREATE)
+, bytes2word(HEAP_SPACE,HEAP_SPACE,RETURN,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v354)
+, useLabel(PS_v315)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v353)
+, CONSTR(0,0,0)
 , 0
 , 0
 , 0
 , 0
 , 200005
-, useLabel(ST_v352)
-,	/* CT_v355: (byte 0) */
-  HW(2,1)
+, useLabel(ST_v314)
+,	/* CT_v316: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized),1)
-, useLabel(PS_v351)
+, useLabel(PS_v313)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_Prelude_46cDIsNormal))
-, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v360)
+, useLabel(CT_v320)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
-  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
-, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
-, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
-, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
-, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
+, bytes2word(7,HEAP_CVAL_N1,12,HEAP_CREATE)
+, bytes2word(HEAP_SPACE,HEAP_SPACE,RETURN,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v359)
+, useLabel(PS_v319)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v358)
+, CONSTR(0,0,0)
 , 0
 , 0
 , 0
 , 0
 , 190005
-, useLabel(ST_v357)
-,	/* CT_v360: (byte 0) */
-  HW(2,1)
+, useLabel(ST_v318)
+,	/* CT_v320: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isInfinite),1)
-, useLabel(PS_v356)
+, useLabel(PS_v317)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_Prelude_46cDIsFinite))
-, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v364)
+, useLabel(CT_v324)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
-  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
-, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
-, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
-, bytes2word(ENDCODE,0,0,0)
+  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
+, bytes2word(7,HEAP_CVAL_N1,12,HEAP_CREATE)
+, bytes2word(HEAP_SPACE,HEAP_SPACE,RETURN,ENDCODE)
 , bytes2word(0,0,0,0)
+, useLabel(PS_v323)
 , 0
-, useLabel(PS_v363)
+, 0
+, 0
+, 0
+, CONSTR(0,0,0)
 , 0
 , 0
 , 0
 , 0
 , 180005
-, useLabel(ST_v362)
-,	/* CT_v364: (byte 0) */
-  HW(1,1)
+, useLabel(ST_v322)
+,	/* CT_v324: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isNaN),1)
-, useLabel(PS_v361)
+, useLabel(PS_v321)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_Prelude_46cDIsNaN))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v368)
+, useLabel(CT_v328)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -384,26 +241,26 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v367)
+, useLabel(PS_v327)
 , 0
 , 0
 , 0
 , 0
 , 150005
-, useLabel(ST_v366)
-,	/* CT_v368: (byte 0) */
+, useLabel(ST_v326)
+,	/* CT_v328: (byte 0) */
   HW(1,2)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat),2)
-, useLabel(PS_v365)
+, useLabel(PS_v325)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46primEncodeDouble))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v372)
+, useLabel(CT_v332)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -412,26 +269,26 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v371)
+, useLabel(PS_v331)
 , 0
 , 0
 , 0
 , 0
 , 140005
-, useLabel(ST_v370)
-,	/* CT_v372: (byte 0) */
+, useLabel(ST_v330)
+,	/* CT_v332: (byte 0) */
   HW(1,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat),1)
-, useLabel(PS_v369)
+, useLabel(PS_v329)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46primDecodeDouble))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v376)
+, useLabel(CT_v336)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
   bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1)
@@ -451,7 +308,7 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
 , 0
 , 0
 , -1073
-, useLabel(PS_v375)
+, useLabel(PS_v335)
 , 0
 , 0
 , 0
@@ -462,38 +319,38 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
 , 0
 , 0
 , 130005
-, useLabel(ST_v374)
-,	/* CT_v376: (byte 0) */
+, useLabel(ST_v334)
+,	/* CT_v336: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange),1)
-, useLabel(PS_v373)
+, useLabel(PS_v333)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v379)
+, useLabel(CT_v339)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
   bytes2word(ZAP_ARG_I1,NEEDSTACK_I16,PUSH_INT_P1,53)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 120005
-, useLabel(ST_v378)
-,	/* CT_v379: (byte 0) */
+, useLabel(ST_v338)
+,	/* CT_v339: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatDigits),1)
-, useLabel(PS_v377)
+, useLabel(PS_v337)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v382)
+, useLabel(CT_v342)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
   bytes2word(ZAP_ARG_I1,NEEDSTACK_I16,PUSH_CADR_N1,8)
@@ -506,20 +363,20 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
 , 0
 , 2
 , 110005
-, useLabel(ST_v381)
-,	/* CT_v382: (byte 0) */
+, useLabel(ST_v341)
+,	/* CT_v342: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix),1)
-, useLabel(PS_v380)
+, useLabel(PS_v340)
 , 0
 , 0
 , 0
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v386)
+, useLabel(CT_v346)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -528,20 +385,20 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
 , bytes2word(1,2,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v385)
+, useLabel(PS_v345)
 , 0
 , 0
 , 0
 , 0
 , 100011
-, useLabel(ST_v384)
-,	/* CT_v386: (byte 0) */
+, useLabel(ST_v344)
+,	/* CT_v346: (byte 0) */
   HW(2,2)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46atan2),2)
-, useLabel(PS_v383)
+, useLabel(PS_v343)
 , 0
 , 0
 , 0
@@ -549,7 +406,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v390)
+, useLabel(CT_v350)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -558,27 +415,27 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
 , bytes2word(1,2,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v389)
+, useLabel(PS_v349)
 , 0
 , 0
 , 0
 , 0
 , 100011
-, useLabel(ST_v388)
-,	/* CT_v390: (byte 0) */
+, useLabel(ST_v348)
+,	/* CT_v350: (byte 0) */
   HW(2,2)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat),2)
-, useLabel(PS_v387)
+, useLabel(PS_v347)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46scaleFloat))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v394)
+, useLabel(CT_v354)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -587,27 +444,27 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v393)
+, useLabel(PS_v353)
 , 0
 , 0
 , 0
 , 0
 , 100011
-, useLabel(ST_v392)
-,	/* CT_v394: (byte 0) */
+, useLabel(ST_v352)
+,	/* CT_v354: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46significand),1)
-, useLabel(PS_v391)
+, useLabel(PS_v351)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46significand))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v398)
+, useLabel(CT_v358)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -616,27 +473,27 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v397)
+, useLabel(PS_v357)
 , 0
 , 0
 , 0
 , 0
 , 100011
-, useLabel(ST_v396)
-,	/* CT_v398: (byte 0) */
+, useLabel(ST_v356)
+,	/* CT_v358: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46exponent),1)
-, useLabel(PS_v395)
+, useLabel(PS_v355)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46exponent))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v402)
+, useLabel(CT_v362)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1,7)
@@ -651,7 +508,7 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(20,HEAP_CVAL_P1,21,HEAP_CVAL_P1)
 , bytes2word(22,RETURN,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v401)
+, useLabel(PS_v361)
 , 0
 , 0
 , 0
@@ -662,14 +519,14 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double[] = {
 , 0
 , 0
 , 100011
-, useLabel(ST_v400)
-,	/* CT_v402: (byte 0) */
+, useLabel(ST_v360)
+,	/* CT_v362: (byte 0) */
   HW(16,0)
 , 0
 ,};
 Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
   VAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double))
-, useLabel(PS_v399)
+, useLabel(PS_v359)
 , 0
 , 0
 , 0
@@ -693,7 +550,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double[] = {
- 	/* ST_v400: (byte 0) */
+ 	/* ST_v360: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -707,7 +564,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
- 	/* ST_v384: (byte 0) */
+ 	/* ST_v344: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -722,7 +579,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
- 	/* ST_v370: (byte 0) */
+ 	/* ST_v330: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -739,7 +596,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
- 	/* ST_v366: (byte 0) */
+ 	/* ST_v326: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -756,7 +613,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
- 	/* ST_v396: (byte 0) */
+ 	/* ST_v356: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -772,7 +629,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
- 	/* ST_v378: (byte 0) */
+ 	/* ST_v338: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -789,7 +646,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
- 	/* ST_v381: (byte 0) */
+ 	/* ST_v341: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -805,7 +662,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
- 	/* ST_v374: (byte 0) */
+ 	/* ST_v334: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -821,7 +678,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
- 	/* ST_v352: (byte 0) */
+ 	/* ST_v314: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -838,7 +695,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
- 	/* ST_v342: (byte 0) */
+ 	/* ST_v306: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -853,7 +710,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
- 	/* ST_v357: (byte 0) */
+ 	/* ST_v318: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -869,7 +726,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
- 	/* ST_v362: (byte 0) */
+ 	/* ST_v322: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -884,7 +741,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
- 	/* ST_v346: (byte 0) */
+ 	/* ST_v310: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -901,7 +758,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
- 	/* ST_v388: (byte 0) */
+ 	/* ST_v348: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -917,7 +774,7 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
 Node PP_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
  };
 Node PC_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
- 	/* ST_v392: (byte 0) */
+ 	/* ST_v352: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -929,261 +786,117 @@ Node PC_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
 , bytes2word(46,115,105,103)
 , bytes2word(110,105,102,105)
 , bytes2word(99,97,110,100)
-,	/* PP_Prelude_46cDIsFinite: (byte 1) */
- 	/* PC_Prelude_46cDIsFinite: (byte 1) */
- 	/* ST_v336: (byte 1) */
-  bytes2word(0,80,114,101)
-, bytes2word(108,117,100,101)
-, bytes2word(46,99,68,73)
-, bytes2word(115,70,105,110)
-,	/* PP_Prelude_46cDIsNaN: (byte 4) */
- 	/* PC_Prelude_46cDIsNaN: (byte 4) */
- 	/* ST_v339: (byte 4) */
-  bytes2word(105,116,101,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-,	/* PP_Prelude_46cDIsNeg: (byte 4) */
- 	/* PC_Prelude_46cDIsNeg: (byte 4) */
- 	/* ST_v330: (byte 4) */
-  bytes2word(78,97,78,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-,	/* PP_Prelude_46cDIsNormal: (byte 4) */
- 	/* PC_Prelude_46cDIsNormal: (byte 4) */
- 	/* ST_v333: (byte 4) */
-  bytes2word(78,101,103,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-, bytes2word(78,111,114,109)
-, bytes2word(97,108,0,0)
-,	/* PS_v338: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46cDIsNaN)
-, useLabel(PC_Prelude_46cDIsNaN)
-,	/* PS_v335: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46cDIsFinite)
-, useLabel(PC_Prelude_46cDIsFinite)
-,	/* PS_v332: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46cDIsNormal)
-, useLabel(PC_Prelude_46cDIsNormal)
-,	/* PS_v329: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46cDIsNeg)
-, useLabel(PC_Prelude_46cDIsNeg)
-,	/* PS_v380: (byte 0) */
+, bytes2word(0,0,0,0)
+,	/* PS_v340: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46floatRadix)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46floatRadix)
-,	/* PS_v377: (byte 0) */
+,	/* PS_v337: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46floatDigits)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46floatDigits)
-,	/* PS_v375: (byte 0) */
+,	/* PS_v335: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46floatRange)
 , useLabel(PC_Prelude_462)
-,	/* PS_v373: (byte 0) */
+,	/* PS_v333: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46floatRange)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46floatRange)
-,	/* PS_v371: (byte 0) */
+,	/* PS_v331: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat)
 , useLabel(PC_Prelude_46primDecodeDouble)
-,	/* PS_v369: (byte 0) */
+,	/* PS_v329: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat)
-,	/* PS_v367: (byte 0) */
+,	/* PS_v327: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat)
 , useLabel(PC_Prelude_46primEncodeDouble)
-,	/* PS_v365: (byte 0) */
+,	/* PS_v325: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat)
-,	/* PS_v363: (byte 0) */
+,	/* PS_v323: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNaN)
-, useLabel(PC_Prelude_46cDIsNaN)
-,	/* PS_v361: (byte 0) */
+, useLabel(PC_Prelude_46False)
+,	/* PS_v321: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNaN)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46isNaN)
-,	/* PS_v359: (byte 0) */
+,	/* PS_v319: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isInfinite)
-, useLabel(PC_Prelude_46not)
-,	/* PS_v358: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isInfinite)
-, useLabel(PC_Prelude_46cDIsFinite)
-,	/* PS_v356: (byte 0) */
+, useLabel(PC_Prelude_46False)
+,	/* PS_v317: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isInfinite)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46isInfinite)
-,	/* PS_v354: (byte 0) */
+,	/* PS_v315: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized)
-, useLabel(PC_Prelude_46not)
-,	/* PS_v353: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized)
-, useLabel(PC_Prelude_46cDIsNormal)
-,	/* PS_v351: (byte 0) */
+, useLabel(PC_Prelude_46False)
+,	/* PS_v313: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized)
-,	/* PS_v349: (byte 0) */
+,	/* PS_v311: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero)
-, useLabel(PC_Prelude_46_38_38)
-,	/* PS_v347: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero)
-, useLabel(PC_Prelude_46cDIsNeg)
-,	/* PS_v345: (byte 0) */
+, useLabel(PC_Prelude_46False)
+,	/* PS_v309: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero)
-,	/* PS_v348: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero)
-, useLabel(PC_Prelude_46Eq_46Prelude_46Double_46_61_61)
-,	/* PS_v343: (byte 0) */
+,	/* PS_v307: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isIEEE)
-, useLabel(PC_Prelude_46True)
-,	/* PS_v341: (byte 0) */
+, useLabel(PC_Prelude_46False)
+,	/* PS_v305: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46isIEEE)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46isIEEE)
-,	/* PS_v397: (byte 0) */
+,	/* PS_v357: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46exponent)
 , useLabel(PC_Prelude_46_95_46exponent)
-,	/* PS_v395: (byte 0) */
+,	/* PS_v355: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46exponent)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46exponent)
-,	/* PS_v393: (byte 0) */
+,	/* PS_v353: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46significand)
 , useLabel(PC_Prelude_46_95_46significand)
-,	/* PS_v391: (byte 0) */
+,	/* PS_v351: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46significand)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46significand)
-,	/* PS_v389: (byte 0) */
+,	/* PS_v349: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat)
 , useLabel(PC_Prelude_46_95_46scaleFloat)
-,	/* PS_v387: (byte 0) */
+,	/* PS_v347: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat)
-,	/* PS_v385: (byte 0) */
+,	/* PS_v345: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46atan2)
 , useLabel(PC_Prelude_46_95_46atan2)
-,	/* PS_v383: (byte 0) */
+,	/* PS_v343: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double_46atan2)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double_46atan2)
-,	/* PS_v399: (byte 0) */
+,	/* PS_v359: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double)
 , useLabel(PC_Prelude_46RealFloat_46Prelude_46Double)
-,	/* PS_v401: (byte 0) */
+,	/* PS_v361: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFloat_46Prelude_46Double)
 , useLabel(PC_Prelude_4616)
 ,};
-
-#include <haskell2c.h>
-#include <HsFFI.h>
-
-/* foreign import ccall "math.h signbit" Prelude.cDIsNeg 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNeg = {"Prelude","Prelude.cDIsNeg","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNeg) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = signbit(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNeg);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isnormal" Prelude.cDIsNormal 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNormal = {"Prelude","Prelude.cDIsNormal","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNormal) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isnormal(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNormal);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isfinite" Prelude.cDIsFinite 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsFinite = {"Prelude","Prelude.cDIsFinite","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsFinite) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isfinite(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsFinite);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isnan" Prelude.cDIsNaN 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNaN = {"Prelude","Prelude.cDIsNaN","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNaN) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isnan(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNaN);
-  C_RETURN(nodeptr);
-}
