@@ -1,60 +1,37 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define FN_Prelude_46cDIsNeg	((void*)startLabel+8)
-#define CT_v330	((void*)startLabel+36)
-#define F0_Prelude_46cDIsNeg	((void*)startLabel+44)
-#define FN_Prelude_46cDIsNormal	((void*)startLabel+56)
-#define CT_v332	((void*)startLabel+84)
-#define F0_Prelude_46cDIsNormal	((void*)startLabel+92)
-#define FN_Prelude_46cDIsFinite	((void*)startLabel+104)
-#define CT_v334	((void*)startLabel+132)
-#define F0_Prelude_46cDIsFinite	((void*)startLabel+140)
-#define FN_Prelude_46cDIsNaN	((void*)startLabel+152)
-#define CT_v336	((void*)startLabel+180)
-#define F0_Prelude_46cDIsNaN	((void*)startLabel+188)
-#define CT_v338	((void*)startLabel+232)
-#define CT_v340	((void*)startLabel+304)
-#define CT_v342	((void*)startLabel+364)
-#define CT_v344	((void*)startLabel+420)
-#define CT_v346	((void*)startLabel+472)
-#define CT_v348	((void*)startLabel+524)
-#define CT_v350	((void*)startLabel+572)
-#define CT_v352	((void*)startLabel+648)
-#define CT_v354	((void*)startLabel+692)
-#define CT_v356	((void*)startLabel+744)
-#define CT_v358	((void*)startLabel+792)
-#define CT_v360	((void*)startLabel+848)
-#define CT_v362	((void*)startLabel+900)
-#define CT_v364	((void*)startLabel+952)
-#define CT_v366	((void*)startLabel+1040)
-#define ST_v365	((void*)startLabel+1116)
-#define ST_v357	((void*)startLabel+1149)
-#define ST_v349	((void*)startLabel+1188)
-#define ST_v347	((void*)startLabel+1233)
-#define ST_v363	((void*)startLabel+1278)
-#define ST_v353	((void*)startLabel+1320)
-#define ST_v355	((void*)startLabel+1365)
-#define ST_v351	((void*)startLabel+1409)
-#define ST_v341	((void*)startLabel+1453)
-#define ST_v337	((void*)startLabel+1501)
-#define ST_v343	((void*)startLabel+1541)
-#define ST_v345	((void*)startLabel+1585)
-#define ST_v339	((void*)startLabel+1624)
-#define ST_v359	((void*)startLabel+1672)
-#define ST_v361	((void*)startLabel+1716)
-#define ST_v333	((void*)startLabel+1761)
-#define ST_v335	((void*)startLabel+1780)
-#define ST_v329	((void*)startLabel+1796)
-#define ST_v331	((void*)startLabel+1812)
+#define CT_v306	((void*)startLabel+40)
+#define CT_v308	((void*)startLabel+92)
+#define CT_v310	((void*)startLabel+144)
+#define CT_v312	((void*)startLabel+196)
+#define CT_v314	((void*)startLabel+248)
+#define CT_v316	((void*)startLabel+296)
+#define CT_v318	((void*)startLabel+344)
+#define CT_v320	((void*)startLabel+420)
+#define CT_v322	((void*)startLabel+464)
+#define CT_v324	((void*)startLabel+516)
+#define CT_v326	((void*)startLabel+564)
+#define CT_v328	((void*)startLabel+620)
+#define CT_v330	((void*)startLabel+672)
+#define CT_v332	((void*)startLabel+724)
+#define CT_v334	((void*)startLabel+812)
+#define ST_v333	((void*)startLabel+888)
+#define ST_v325	((void*)startLabel+921)
+#define ST_v317	((void*)startLabel+960)
+#define ST_v315	((void*)startLabel+1005)
+#define ST_v331	((void*)startLabel+1050)
+#define ST_v321	((void*)startLabel+1092)
+#define ST_v323	((void*)startLabel+1137)
+#define ST_v319	((void*)startLabel+1181)
+#define ST_v309	((void*)startLabel+1225)
+#define ST_v305	((void*)startLabel+1273)
+#define ST_v311	((void*)startLabel+1313)
+#define ST_v313	((void*)startLabel+1357)
+#define ST_v307	((void*)startLabel+1396)
+#define ST_v327	((void*)startLabel+1444)
+#define ST_v329	((void*)startLabel+1488)
 extern Node TM_Prelude[];
-void FR_Prelude_46cDIsNeg(void);
-void FR_Prelude_46cDIsNormal(void);
-void FR_Prelude_46cDIsFinite(void);
-void FR_Prelude_46cDIsNaN(void);
-extern Node FN_Prelude_46Eq_46Prelude_46Double_46_61_61[];
-extern Node FN_Prelude_46_38_38[];
-extern Node FN_Prelude_46not[];
 extern Node FN_Prelude_46primEncodeDouble[];
 extern Node FN_Prelude_46primDecodeDouble[];
 extern Node FN_Prelude_46_95_46atan2[];
@@ -67,67 +44,7 @@ extern Node CF_Prelude_46Floating_46Prelude_46Double[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v330)
-,	/* FN_Prelude_46cDIsNeg: (byte 0) */
-  useLabel(TM_Prelude)
-, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNeg)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 270001
-, useLabel(ST_v329)
-,	/* CT_v330: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNeg: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNeg),1)
-, bytes2word(1,0,0,1)
-, useLabel(CT_v332)
-,	/* FN_Prelude_46cDIsNormal: (byte 0) */
-  useLabel(TM_Prelude)
-, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNormal)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 260001
-, useLabel(ST_v331)
-,	/* CT_v332: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNormal: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNormal),1)
-, bytes2word(1,0,0,1)
-, useLabel(CT_v334)
-,	/* FN_Prelude_46cDIsFinite: (byte 0) */
-  useLabel(TM_Prelude)
-, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsFinite)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 250001
-, useLabel(ST_v333)
-,	/* CT_v334: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsFinite: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsFinite),1)
-, bytes2word(1,0,0,1)
-, useLabel(CT_v336)
-,	/* FN_Prelude_46cDIsNaN: (byte 0) */
-  useLabel(TM_Prelude)
-, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
-, useLabel(FR_Prelude_46cDIsNaN)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
-, bytes2word(0,0,0,0)
-, 240001
-, useLabel(ST_v335)
-,	/* CT_v336: (byte 0) */
-  HW(0,1)
-, 0
-,	/* F0_Prelude_46cDIsNaN: (byte 0) */
-  CAPTAG(useLabel(FN_Prelude_46cDIsNaN),1)
-, bytes2word(1,0,0,1)
-, useLabel(CT_v338)
+, useLabel(CT_v306)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
   useLabel(TM_Prelude)
@@ -135,99 +52,90 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, CONSTR(1,0,0)
+, CONSTR(0,0,0)
 , 220005
-, useLabel(ST_v337)
-,	/* CT_v338: (byte 0) */
+, useLabel(ST_v305)
+,	/* CT_v306: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isIEEE[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isIEEE),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v340)
+, useLabel(CT_v308)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
   useLabel(TM_Prelude)
-, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
-, bytes2word(HEAP_CVAL_I4,HEAP_ARG,1,HEAP_CADR_N1)
-, bytes2word(5,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
-, bytes2word(6,HEAP_OFF_N1,5,RETURN_EVAL)
-, bytes2word(ENDCODE,0,0,0)
+, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
+, bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, CONSTRW(2,0)
-, 0
-, 0
+, CONSTR(0,0,0)
 , 210005
-, useLabel(ST_v339)
-,	/* CT_v340: (byte 0) */
-  HW(3,1)
+, useLabel(ST_v307)
+,	/* CT_v308: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isNegativeZero),1)
-, VAPTAG(useLabel(FN_Prelude_46cDIsNeg))
-, VAPTAG(useLabel(FN_Prelude_46Eq_46Prelude_46Double_46_61_61))
-, VAPTAG(useLabel(FN_Prelude_46_38_38))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v342)
+, useLabel(CT_v310)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
   useLabel(TM_Prelude)
-, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
-, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
+, bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
+, 0
+, CONSTR(0,0,0)
 , 200005
-, useLabel(ST_v341)
-,	/* CT_v342: (byte 0) */
-  HW(2,1)
+, useLabel(ST_v309)
+,	/* CT_v310: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isDenormalized),1)
-, VAPTAG(useLabel(FN_Prelude_46cDIsNormal))
-, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v344)
+, useLabel(CT_v312)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
   useLabel(TM_Prelude)
-, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
-, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
+, bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
+, 0
+, CONSTR(0,0,0)
 , 190005
-, useLabel(ST_v343)
-,	/* CT_v344: (byte 0) */
-  HW(2,1)
+, useLabel(ST_v311)
+,	/* CT_v312: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isInfinite[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isInfinite),1)
-, VAPTAG(useLabel(FN_Prelude_46cDIsFinite))
-, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v346)
+, useLabel(CT_v314)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
   useLabel(TM_Prelude)
-, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
-, bytes2word(1,RETURN_EVAL,ENDCODE,0)
+, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
+, bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
+, 0
+, CONSTR(0,0,0)
 , 180005
-, useLabel(ST_v345)
-,	/* CT_v346: (byte 0) */
-  HW(1,1)
+, useLabel(ST_v313)
+,	/* CT_v314: (byte 0) */
+  HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46isNaN[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46isNaN),1)
-, VAPTAG(useLabel(FN_Prelude_46cDIsNaN))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v348)
+, useLabel(CT_v316)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
   useLabel(TM_Prelude)
@@ -235,8 +143,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
 , bytes2word(1,2,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 150005
-, useLabel(ST_v347)
-,	/* CT_v348: (byte 0) */
+, useLabel(ST_v315)
+,	/* CT_v316: (byte 0) */
   HW(1,2)
 , 0
 ,};
@@ -244,7 +152,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46encodeFloat),2)
 , VAPTAG(useLabel(FN_Prelude_46primEncodeDouble))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v350)
+, useLabel(CT_v318)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
   useLabel(TM_Prelude)
@@ -252,8 +160,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 140005
-, useLabel(ST_v349)
-,	/* CT_v350: (byte 0) */
+, useLabel(ST_v317)
+,	/* CT_v318: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -261,7 +169,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46decodeFloat),1)
 , VAPTAG(useLabel(FN_Prelude_46primDecodeDouble))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v352)
+, useLabel(CT_v320)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
   useLabel(TM_Prelude)
@@ -276,15 +184,15 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
 , -1073
 , CONSTR(0,2,0)
 , 130005
-, useLabel(ST_v351)
-,	/* CT_v352: (byte 0) */
+, useLabel(ST_v319)
+,	/* CT_v320: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatRange[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatRange),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v354)
+, useLabel(CT_v322)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
   useLabel(TM_Prelude)
@@ -292,15 +200,15 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 120005
-, useLabel(ST_v353)
-,	/* CT_v354: (byte 0) */
+, useLabel(ST_v321)
+,	/* CT_v322: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatDigits[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatDigits),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v356)
+, useLabel(CT_v324)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
   useLabel(TM_Prelude)
@@ -310,8 +218,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
 , CONSTRW(1,0)
 , 2
 , 110005
-, useLabel(ST_v355)
-,	/* CT_v356: (byte 0) */
+, useLabel(ST_v323)
+,	/* CT_v324: (byte 0) */
   HW(0,1)
 , 0
 ,};
@@ -319,7 +227,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46floatRadix[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Double_46floatRadix),1)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v358)
+, useLabel(CT_v326)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
   useLabel(TM_Prelude)
@@ -327,8 +235,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 100011
-, useLabel(ST_v357)
-,	/* CT_v358: (byte 0) */
+, useLabel(ST_v325)
+,	/* CT_v326: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -338,7 +246,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46atan2[] = {
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v360)
+, useLabel(CT_v328)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
   useLabel(TM_Prelude)
@@ -346,8 +254,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 100011
-, useLabel(ST_v359)
-,	/* CT_v360: (byte 0) */
+, useLabel(ST_v327)
+,	/* CT_v328: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -356,7 +264,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46scaleFloat))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v362)
+, useLabel(CT_v330)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
   useLabel(TM_Prelude)
@@ -364,8 +272,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 100011
-, useLabel(ST_v361)
-,	/* CT_v362: (byte 0) */
+, useLabel(ST_v329)
+,	/* CT_v330: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -374,7 +282,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46significand[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46significand))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v364)
+, useLabel(CT_v332)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
   useLabel(TM_Prelude)
@@ -382,8 +290,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 100011
-, useLabel(ST_v363)
-,	/* CT_v364: (byte 0) */
+, useLabel(ST_v331)
+,	/* CT_v332: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -392,7 +300,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Double_46exponent[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46exponent))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Double)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v366)
+, useLabel(CT_v334)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Double[] = {
   useLabel(TM_Prelude)
@@ -409,8 +317,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Double[] = {
 , 0
 , CONSTR(0,16,0)
 , 100011
-, useLabel(ST_v365)
-,	/* CT_v366: (byte 0) */
+, useLabel(ST_v333)
+,	/* CT_v334: (byte 0) */
   HW(16,0)
 , 0
 ,};
@@ -432,7 +340,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Double_46scaleFloat)
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Double_46exponent)
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Double_46floatRadix)
-,	/* ST_v365: (byte 0) */
+,	/* ST_v333: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -441,7 +349,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,68,111)
 , bytes2word(117,98,108,101)
-,	/* ST_v357: (byte 1) */
+,	/* ST_v325: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -451,7 +359,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(100,101,46,68)
 , bytes2word(111,117,98,108)
 , bytes2word(101,46,97,116)
-,	/* ST_v349: (byte 4) */
+,	/* ST_v317: (byte 4) */
   bytes2word(97,110,50,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -464,7 +372,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(46,100,101,99)
 , bytes2word(111,100,101,70)
 , bytes2word(108,111,97,116)
-,	/* ST_v347: (byte 1) */
+,	/* ST_v315: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -476,7 +384,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(101,46,101,110)
 , bytes2word(99,111,100,101)
 , bytes2word(70,108,111,97)
-,	/* ST_v363: (byte 2) */
+,	/* ST_v331: (byte 2) */
   bytes2word(116,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -487,7 +395,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(68,111,117,98)
 , bytes2word(108,101,46,101)
 , bytes2word(120,112,111,110)
-,	/* ST_v353: (byte 4) */
+,	/* ST_v321: (byte 4) */
   bytes2word(101,110,116,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -500,7 +408,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(46,102,108,111)
 , bytes2word(97,116,68,105)
 , bytes2word(103,105,116,115)
-,	/* ST_v355: (byte 1) */
+,	/* ST_v323: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -512,7 +420,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(101,46,102,108)
 , bytes2word(111,97,116,82)
 , bytes2word(97,100,105,120)
-,	/* ST_v351: (byte 1) */
+,	/* ST_v319: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -524,7 +432,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(101,46,102,108)
 , bytes2word(111,97,116,82)
 , bytes2word(97,110,103,101)
-,	/* ST_v341: (byte 1) */
+,	/* ST_v309: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -537,7 +445,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(68,101,110,111)
 , bytes2word(114,109,97,108)
 , bytes2word(105,122,101,100)
-,	/* ST_v337: (byte 1) */
+,	/* ST_v305: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -548,7 +456,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(111,117,98,108)
 , bytes2word(101,46,105,115)
 , bytes2word(73,69,69,69)
-,	/* ST_v343: (byte 1) */
+,	/* ST_v311: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -560,7 +468,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(101,46,105,115)
 , bytes2word(73,110,102,105)
 , bytes2word(110,105,116,101)
-,	/* ST_v345: (byte 1) */
+,	/* ST_v313: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -570,7 +478,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(100,101,46,68)
 , bytes2word(111,117,98,108)
 , bytes2word(101,46,105,115)
-,	/* ST_v339: (byte 4) */
+,	/* ST_v307: (byte 4) */
   bytes2word(78,97,78,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -583,7 +491,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(46,105,115,78)
 , bytes2word(101,103,97,116)
 , bytes2word(105,118,101,90)
-,	/* ST_v359: (byte 4) */
+,	/* ST_v327: (byte 4) */
   bytes2word(101,114,111,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -595,7 +503,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(117,98,108,101)
 , bytes2word(46,115,99,97)
 , bytes2word(108,101,70,108)
-,	/* ST_v361: (byte 4) */
+,	/* ST_v329: (byte 4) */
   bytes2word(111,97,116,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -608,109 +516,5 @@ Node CF_Prelude_46RealFloat_46Prelude_46Double[] = {
 , bytes2word(46,115,105,103)
 , bytes2word(110,105,102,105)
 , bytes2word(99,97,110,100)
-,	/* ST_v333: (byte 1) */
-  bytes2word(0,80,114,101)
-, bytes2word(108,117,100,101)
-, bytes2word(46,99,68,73)
-, bytes2word(115,70,105,110)
-,	/* ST_v335: (byte 4) */
-  bytes2word(105,116,101,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-,	/* ST_v329: (byte 4) */
-  bytes2word(78,97,78,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-,	/* ST_v331: (byte 4) */
-  bytes2word(78,101,103,0)
-, bytes2word(80,114,101,108)
-, bytes2word(117,100,101,46)
-, bytes2word(99,68,73,115)
-, bytes2word(78,111,114,109)
-, bytes2word(97,108,0,0)
+, bytes2word(0,0,0,0)
 ,};
-
-#include <haskell2c.h>
-#include <HsFFI.h>
-
-/* foreign import ccall "math.h signbit" Prelude.cDIsNeg 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNeg = {"Prelude","Prelude.cDIsNeg","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNeg) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = signbit(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNeg);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isnormal" Prelude.cDIsNormal 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNormal = {"Prelude","Prelude.cDIsNormal","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNormal) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isnormal(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNormal);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isfinite" Prelude.cDIsFinite 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsFinite = {"Prelude","Prelude.cDIsFinite","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsFinite) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isfinite(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsFinite);
-  C_RETURN(nodeptr);
-}
-
-/* foreign import ccall "math.h isnan" Prelude.cDIsNaN 1 :: Prelude.Double -> Prelude.Bool */
-#include "math.h"
-#ifdef PROFILE
-static SInfo pf_Prelude_46cDIsNaN = {"Prelude","Prelude.cDIsNaN","Prelude.Bool"};
-#endif
-C_HEADER(FR_Prelude_46cDIsNaN) {
-  NodePtr nodeptr;
-  HsBool result;
-  double arg1;
-  nodeptr = C_GETARG1(1);
-  IND_REMOVE(nodeptr);
-  arg1 = (double)get_double_value(nodeptr);
-
-  result = isnan(arg1);
-
-  nodeptr = nhc_mkBool(result);
-  INIT_PROFINFO(nodeptr,&pf_Prelude_46cDIsNaN);
-  C_RETURN(nodeptr);
-}
